AddToWalletDetails class abstract

The Details object that provides some additional result

Available extensions
Annotations
  • @freezed

Constructors

AddToWalletDetails({CanAddToWalletErrorStatus? status, String? token})
const
factory
AddToWalletDetails.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $AddToWalletDetailsCopyWith<AddToWalletDetails>
Create a copy of AddToWalletDetails with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status CanAddToWalletErrorStatus?
The status of the can add to wallet request in case it failed.
no setterinherited
token String?
The card token
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AddToWalletDetails value)) → TResult

Available on AddToWalletDetails, provided by the AddToWalletDetailsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AddToWalletDetails value)?) → TResult?

Available on AddToWalletDetails, provided by the AddToWalletDetailsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AddToWalletDetails value)?, {required TResult orElse()}) → TResult

Available on AddToWalletDetails, provided by the AddToWalletDetailsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(CanAddToWalletErrorStatus? status, String? token)?, {required TResult orElse()}) → TResult

Available on AddToWalletDetails, provided by the AddToWalletDetailsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AddToWalletDetails to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(CanAddToWalletErrorStatus? status, String? token)) → TResult

Available on AddToWalletDetails, provided by the AddToWalletDetailsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(CanAddToWalletErrorStatus? status, String? token)?) → TResult?

Available on AddToWalletDetails, provided by the AddToWalletDetailsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited