Address class abstract

Address information

Available extensions
Annotations
  • @freezed

Constructors

Address({required String? city, required String? country, required String? line1, required String? line2, required String? postalCode, required String? state})
const
factory
Address.fromJson(Map<String, dynamic> json)
factory

Properties

city String?
City, town or district.
no setterinherited
copyWith → $AddressCopyWith<Address>
Create a copy of Address with the given fields replaced by the non-null parameter values.
no setterinherited
country String?
Country
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
line1 String?
Address line1 (e.g. Street, C/O , PO Box).
no setterinherited
line2 String?
Address line2 (e.g. building, appartment or unit).
no setterinherited
postalCode String?
ZIP or postal code.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
State or province.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Address value)) → TResult

Available on Address, provided by the AddressPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Address value)?) → TResult?

Available on Address, provided by the AddressPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Address value)?, {required TResult orElse()}) → TResult

Available on Address, provided by the AddressPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? city, String? country, String? line1, String? line2, String? postalCode, String? state)?, {required TResult orElse()}) → TResult

Available on Address, provided by the AddressPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Address to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? city, String? country, String? line1, String? line2, String? postalCode, String? state)) → TResult

Available on Address, provided by the AddressPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? city, String? country, String? line1, String? line2, String? postalCode, String? state)?) → TResult?

Available on Address, provided by the AddressPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited