ApplePaySheetError class abstract

Available extensions
Annotations
  • @Freezed.new(unionKey: 'errorType')

Constructors

ApplePaySheetError.expiredCouponCode({String? message})
Use this in case the entered coupon code has expired
const
factory
ApplePaySheetError.fromJson(Map<String, dynamic> json)
factory
ApplePaySheetError.invalidCouponCode({String? message})
Use this in case the entered coupon code is wrong
const
factory
ApplePaySheetError.invalidShippingField({required InvalidShippingField field, String? message})
Use this in case the shipping address is invalid
const
factory
ApplePaySheetError.unserviceableShippingAddress({String? message})
Use this in case you cannot deliver to the shipping address
const
factory

Properties

copyWith → $ApplePaySheetErrorCopyWith<ApplePaySheetError>
Create a copy of ApplePaySheetError with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult invalidShippingField(_ApplePaySheetErrorInvalidShipping value), required TResult unserviceableShippingAddress(_ApplePaySheetErrorUnserviceableShipping value), required TResult invalidCouponCode(_ApplePaySheetErrorInvalidCouponCode value), required TResult expiredCouponCode(_ApplePaySheetErrorExpiredCouponCode value)}) → TResult

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? invalidShippingField(_ApplePaySheetErrorInvalidShipping value)?, TResult? unserviceableShippingAddress(_ApplePaySheetErrorUnserviceableShipping value)?, TResult? invalidCouponCode(_ApplePaySheetErrorInvalidCouponCode value)?, TResult? expiredCouponCode(_ApplePaySheetErrorExpiredCouponCode value)?}) → TResult?

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult invalidShippingField(_ApplePaySheetErrorInvalidShipping value)?, TResult unserviceableShippingAddress(_ApplePaySheetErrorUnserviceableShipping value)?, TResult invalidCouponCode(_ApplePaySheetErrorInvalidCouponCode value)?, TResult expiredCouponCode(_ApplePaySheetErrorExpiredCouponCode value)?, required TResult orElse()}) → TResult

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult invalidShippingField(InvalidShippingField field, String? message)?, TResult unserviceableShippingAddress(String? message)?, TResult invalidCouponCode(String? message)?, TResult expiredCouponCode(String? message)?, required TResult orElse()}) → TResult

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ApplePaySheetError to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult invalidShippingField(InvalidShippingField field, String? message), required TResult unserviceableShippingAddress(String? message), required TResult invalidCouponCode(String? message), required TResult expiredCouponCode(String? message)}) → TResult

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? invalidShippingField(InvalidShippingField field, String? message)?, TResult? unserviceableShippingAddress(String? message)?, TResult? invalidCouponCode(String? message)?, TResult? expiredCouponCode(String? message)?}) → TResult?

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited