ApplePaySheetErrorPatterns extension

Adds pattern-matching-related methods to ApplePaySheetError.

on

Methods

map<TResult extends Object?>({required TResult invalidShippingField(_ApplePaySheetErrorInvalidShipping value), required TResult unserviceableShippingAddress(_ApplePaySheetErrorUnserviceableShipping value), required TResult invalidCouponCode(_ApplePaySheetErrorInvalidCouponCode value), required TResult expiredCouponCode(_ApplePaySheetErrorExpiredCouponCode value)}) → TResult

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? invalidShippingField(_ApplePaySheetErrorInvalidShipping value)?, TResult? unserviceableShippingAddress(_ApplePaySheetErrorUnserviceableShipping value)?, TResult? invalidCouponCode(_ApplePaySheetErrorInvalidCouponCode value)?, TResult? expiredCouponCode(_ApplePaySheetErrorExpiredCouponCode value)?}) → TResult?

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult invalidShippingField(_ApplePaySheetErrorInvalidShipping value)?, TResult unserviceableShippingAddress(_ApplePaySheetErrorUnserviceableShipping value)?, TResult invalidCouponCode(_ApplePaySheetErrorInvalidCouponCode value)?, TResult expiredCouponCode(_ApplePaySheetErrorExpiredCouponCode value)?, required TResult orElse()}) → TResult

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult invalidShippingField(InvalidShippingField field, String? message)?, TResult unserviceableShippingAddress(String? message)?, TResult invalidCouponCode(String? message)?, TResult expiredCouponCode(String? message)?, required TResult orElse()}) → TResult

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult invalidShippingField(InvalidShippingField field, String? message), required TResult unserviceableShippingAddress(String? message), required TResult invalidCouponCode(String? message), required TResult expiredCouponCode(String? message)}) → TResult

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? invalidShippingField(InvalidShippingField field, String? message)?, TResult? unserviceableShippingAddress(String? message)?, TResult? invalidCouponCode(String? message)?, TResult? expiredCouponCode(String? message)?}) → TResult?

Available on ApplePaySheetError, provided by the ApplePaySheetErrorPatterns extension

A variant of when that fallback to returning null