BankAccount class abstract
Bank account data related to the token
- Available extensions
- Annotations
-
- @freezed
Constructors
- BankAccount({required String id, BankAccountHolderType? accountHolderType, String? bankName, String? accountHolderName, String? country, String? currency, String? routingNumber, BankAccountStatus? status, String? fingerprint, String? last4})
-
constfactory
-
BankAccount.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountHolderName → String?
-
Full name of the account holder
no setterinherited
- accountHolderType → BankAccountHolderType?
-
Entity that is holder of the account.
no setterinherited
- bankName → String?
-
Name of the bank where the account is registered.
no setterinherited
-
copyWith
→ $BankAccountCopyWith<
BankAccount> -
Create a copy of BankAccount
with the given fields replaced by the non-null parameter values.
no setterinherited
- country → String?
-
2 letter code of the country where the account is located
no setterinherited
- currency → String?
-
The three letter ISO 4217 code for the currency.
no setterinherited
- fingerprint → String?
-
Uniquely identifies the particular bank account.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique id for this bank account
no setterinherited
- last4 → String?
-
Last four numbers of the bank account number
no setterinherited
- routingNumber → String?
-
The routing number of the bank account (e.g. needer for US accounts).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → BankAccountStatus?
-
Status of the bank account.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_BankAccount value)) → TResult -
Available on BankAccount, provided by the BankAccountPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_BankAccount value)?) → TResult? -
Available on BankAccount, provided by the BankAccountPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_BankAccount value)?, {required TResult orElse()}) → TResult -
Available on BankAccount, provided by the BankAccountPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, BankAccountHolderType? accountHolderType, String? bankName, String? accountHolderName, String? country, String? currency, String? routingNumber, BankAccountStatus? status, String? fingerprint, String? last4)?, {required TResult orElse()}) → TResult -
Available on BankAccount, provided by the BankAccountPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BankAccount to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, BankAccountHolderType? accountHolderType, String? bankName, String? accountHolderName, String? country, String? currency, String? routingNumber, BankAccountStatus? status, String? fingerprint, String? last4)) → TResult -
Available on BankAccount, provided by the BankAccountPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, BankAccountHolderType? accountHolderType, String? bankName, String? accountHolderName, String? country, String? currency, String? routingNumber, BankAccountStatus? status, String? fingerprint, String? last4)?) → TResult? -
Available on BankAccount, provided by the BankAccountPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited