BillingAddressConfig class abstract
Billing address collection config for Google Pay.
- Available extensions
- Annotations
-
- @freezed
Constructors
- BillingAddressConfig({bool? isRequired, BillingAddressFormat? format, bool? isPhoneNumberRequired})
-
constfactory
-
BillingAddressConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $BillingAddressConfigCopyWith<
BillingAddressConfig> -
Create a copy of BillingAddressConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- format → BillingAddressFormat?
-
Desired format
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPhoneNumberRequired → bool?
-
If
truecustomer needs to provide a phonenummer in order to process the transaction.no setterinherited - isRequired → bool?
-
If
trueGoogle pay requires a Billing address in order to process the payment.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_BillingAddressConfig value)) → TResult -
Available on BillingAddressConfig, provided by the BillingAddressConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_BillingAddressConfig value)?) → TResult? -
Available on BillingAddressConfig, provided by the BillingAddressConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_BillingAddressConfig value)?, {required TResult orElse()}) → TResult -
Available on BillingAddressConfig, provided by the BillingAddressConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(bool? isRequired, BillingAddressFormat? format, bool? isPhoneNumberRequired)?, {required TResult orElse()}) → TResult -
Available on BillingAddressConfig, provided by the BillingAddressConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BillingAddressConfig to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(bool? isRequired, BillingAddressFormat? format, bool? isPhoneNumberRequired)) → TResult -
Available on BillingAddressConfig, provided by the BillingAddressConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(bool? isRequired, BillingAddressFormat? format, bool? isPhoneNumberRequired)?) → TResult? -
Available on BillingAddressConfig, provided by the BillingAddressConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited