BillingDetailsCollectionConfiguration class abstract

Available extensions
Annotations
  • @freezed

Constructors

BillingDetailsCollectionConfiguration({CollectionMode? name, CollectionMode? phone, CollectionMode? email, AddressCollectionMode? address, bool? attachDefaultsToPaymentMethod})
const
factory
BillingDetailsCollectionConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

address AddressCollectionMode?
How to collect the billing address.
no setterinherited
attachDefaultsToPaymentMethod bool?
Whether the values included in Configuration.defaultBillingDetails should be attached to the payment method, this includes fields that aren't displayed in the form.
no setterinherited
copyWith → $BillingDetailsCollectionConfigurationCopyWith<BillingDetailsCollectionConfiguration>
Create a copy of BillingDetailsCollectionConfiguration with the given fields replaced by the non-null parameter values.
no setterinherited
email CollectionMode?
How to collect the email field.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name CollectionMode?
How to collect the name field.
no setterinherited
phone CollectionMode?
How to collect the phone field.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_BillingDetailsCollectionConfiguration value)) → TResult

Available on BillingDetailsCollectionConfiguration, provided by the BillingDetailsCollectionConfigurationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_BillingDetailsCollectionConfiguration value)?) → TResult?

Available on BillingDetailsCollectionConfiguration, provided by the BillingDetailsCollectionConfigurationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_BillingDetailsCollectionConfiguration value)?, {required TResult orElse()}) → TResult

Available on BillingDetailsCollectionConfiguration, provided by the BillingDetailsCollectionConfigurationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(CollectionMode? name, CollectionMode? phone, CollectionMode? email, AddressCollectionMode? address, bool? attachDefaultsToPaymentMethod)?, {required TResult orElse()}) → TResult

Available on BillingDetailsCollectionConfiguration, provided by the BillingDetailsCollectionConfigurationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this BillingDetailsCollectionConfiguration to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(CollectionMode? name, CollectionMode? phone, CollectionMode? email, AddressCollectionMode? address, bool? attachDefaultsToPaymentMethod)) → TResult

Available on BillingDetailsCollectionConfiguration, provided by the BillingDetailsCollectionConfigurationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(CollectionMode? name, CollectionMode? phone, CollectionMode? email, AddressCollectionMode? address, bool? attachDefaultsToPaymentMethod)?) → TResult?

Available on BillingDetailsCollectionConfiguration, provided by the BillingDetailsCollectionConfigurationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited