CanAddCardToWalletParams class abstract

The params for checking if a card is in the wallet.

Available extensions
Annotations
  • @freezed

Constructors

CanAddCardToWalletParams({String? primaryAccountIdentifier, required String cardLastFour, bool? testEnv, bool? hasPairedAppleWatch, bool? supportsTapToPay})
const
factory
CanAddCardToWalletParams.fromJson(Map<String, dynamic> json)
factory

Properties

cardLastFour String
Last 4 digits of the card number. Required for Android.
no setterinherited
copyWith → $CanAddCardToWalletParamsCopyWith<CanAddCardToWalletParams>
Create a copy of CanAddCardToWalletParams with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasPairedAppleWatch bool?
iOS only. Set this to true if: your user has an Apple Watch device currently paired, and you want to check that device for the presence of the specified card.
no setterinherited
primaryAccountIdentifier String?
The primary_account_identifier value from the issued card. Can be an empty string.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsTapToPay bool?
Android only, defaults to true. Set this to false if you'd like to allow users without NFC-enabled devices to add cards to the wallet. NFC is required for paying in stores.
no setterinherited
testEnv bool?
iOS only. Set this to true until shipping through TestFlight || App Store. If false, you must be using live cards, and have the proper iOS entitlement set up. See https://stripe.com/docs/issuing/cards/digital-wallets?platform=react-native#requesting-access-for-ios
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CanAddCardToWalletParams value)) → TResult

Available on CanAddCardToWalletParams, provided by the CanAddCardToWalletParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CanAddCardToWalletParams value)?) → TResult?

Available on CanAddCardToWalletParams, provided by the CanAddCardToWalletParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CanAddCardToWalletParams value)?, {required TResult orElse()}) → TResult

Available on CanAddCardToWalletParams, provided by the CanAddCardToWalletParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? primaryAccountIdentifier, String cardLastFour, bool? testEnv, bool? hasPairedAppleWatch, bool? supportsTapToPay)?, {required TResult orElse()}) → TResult

Available on CanAddCardToWalletParams, provided by the CanAddCardToWalletParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CanAddCardToWalletParams to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? primaryAccountIdentifier, String cardLastFour, bool? testEnv, bool? hasPairedAppleWatch, bool? supportsTapToPay)) → TResult

Available on CanAddCardToWalletParams, provided by the CanAddCardToWalletParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? primaryAccountIdentifier, String cardLastFour, bool? testEnv, bool? hasPairedAppleWatch, bool? supportsTapToPay)?) → TResult?

Available on CanAddCardToWalletParams, provided by the CanAddCardToWalletParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited