hasPairedAppleWatch property

bool? get hasPairedAppleWatch
inherited

iOS only. Set this to true if: your user has an Apple Watch device currently paired, and you want to check that device for the presence of the specified card.

Implementation

bool? get testEnv;/// iOS only. Set this to `true` if: your user has an Apple Watch device currently paired, and you want to check that device for the presence of the specified card.
bool? get hasPairedAppleWatch;