CanAddCardToWalletResult class abstract

The result of checking if a card can be added to the wallet.

Available extensions
Annotations
  • @freezed

Constructors

CanAddCardToWalletResult({required bool canAddCard, CanAddCardToDetails? details})
const
factory
CanAddCardToWalletResult.fromJson(Map<String, dynamic> json)
factory

Properties

canAddCard bool
no setterinherited
copyWith → $CanAddCardToWalletResultCopyWith<CanAddCardToWalletResult>
Create a copy of CanAddCardToWalletResult with the given fields replaced by the non-null parameter values.
no setterinherited
details CanAddCardToDetails?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CanAddCardToWalletResult value)) → TResult

Available on CanAddCardToWalletResult, provided by the CanAddCardToWalletResultPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CanAddCardToWalletResult value)?) → TResult?

Available on CanAddCardToWalletResult, provided by the CanAddCardToWalletResultPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CanAddCardToWalletResult value)?, {required TResult orElse()}) → TResult

Available on CanAddCardToWalletResult, provided by the CanAddCardToWalletResultPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool canAddCard, CanAddCardToDetails? details)?, {required TResult orElse()}) → TResult

Available on CanAddCardToWalletResult, provided by the CanAddCardToWalletResultPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CanAddCardToWalletResult to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool canAddCard, CanAddCardToDetails? details)) → TResult

Available on CanAddCardToWalletResult, provided by the CanAddCardToWalletResultPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool canAddCard, CanAddCardToDetails? details)?) → TResult?

Available on CanAddCardToWalletResult, provided by the CanAddCardToWalletResultPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited