CardBrandAcceptance class abstract

Options to block certain card brands on the client

Available extensions
Annotations
  • @freezed

Constructors

CardBrandAcceptance.all({@Default.new(CardBrandAcceptanceFilter.all) CardBrandAcceptanceFilter filter})
const
factory
CardBrandAcceptance.allowed({@Default.new(CardBrandAcceptanceFilter.allowed) CardBrandAcceptanceFilter filter, required List<CardBrandCategory> brands})
const
factory
CardBrandAcceptance.disallowed({@Default.new(CardBrandAcceptanceFilter.disallowed) CardBrandAcceptanceFilter filter, required List<CardBrandCategory> brands})
const
factory
CardBrandAcceptance.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $CardBrandAcceptanceCopyWith<CardBrandAcceptance>
Create a copy of CardBrandAcceptance with the given fields replaced by the non-null parameter values.
no setterinherited
filter CardBrandAcceptanceFilter
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult all(_CardBrandAcceptanceAll value), required TResult allowed(_CardBrandAcceptanceAllowed value), required TResult disallowed(_CardBrandAcceptanceDisallowed value)}) → TResult

Available on CardBrandAcceptance, provided by the CardBrandAcceptancePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? all(_CardBrandAcceptanceAll value)?, TResult? allowed(_CardBrandAcceptanceAllowed value)?, TResult? disallowed(_CardBrandAcceptanceDisallowed value)?}) → TResult?

Available on CardBrandAcceptance, provided by the CardBrandAcceptancePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult all(_CardBrandAcceptanceAll value)?, TResult allowed(_CardBrandAcceptanceAllowed value)?, TResult disallowed(_CardBrandAcceptanceDisallowed value)?, required TResult orElse()}) → TResult

Available on CardBrandAcceptance, provided by the CardBrandAcceptancePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult all(CardBrandAcceptanceFilter filter)?, TResult allowed(CardBrandAcceptanceFilter filter, List<CardBrandCategory> brands)?, TResult disallowed(CardBrandAcceptanceFilter filter, List<CardBrandCategory> brands)?, required TResult orElse()}) → TResult

Available on CardBrandAcceptance, provided by the CardBrandAcceptancePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CardBrandAcceptance to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult all(CardBrandAcceptanceFilter filter), required TResult allowed(CardBrandAcceptanceFilter filter, List<CardBrandCategory> brands), required TResult disallowed(CardBrandAcceptanceFilter filter, List<CardBrandCategory> brands)}) → TResult

Available on CardBrandAcceptance, provided by the CardBrandAcceptancePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? all(CardBrandAcceptanceFilter filter)?, TResult? allowed(CardBrandAcceptanceFilter filter, List<CardBrandCategory> brands)?, TResult? disallowed(CardBrandAcceptanceFilter filter, List<CardBrandCategory> brands)?}) → TResult?

Available on CardBrandAcceptance, provided by the CardBrandAcceptancePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited