CardFundingType enum

Card funding types that can be filtered. Note: This is a private preview API and will have no effect unless your Stripe account is enrolled in the private preview.

Inheritance
Available extensions

Values

debit → const CardFundingType

Debit cards

credit → const CardFundingType

Credit cards

prepaid → const CardFundingType

Prepaid cards

unknown → const CardFundingType

Unknown or undetermined funding type. Include this if you want to accept cards where the funding type cannot be determined from card metadata.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CardFundingType>
A constant List of the values in this enum, in order of their declaration.