textErrorColor property

  1. @JsonKey.new(toJson: ColorKey.toJson, fromJson: ColorKey.fromJson)
Color? get textErrorColor
inherited

Color of the input in case incorrect data is entered.

Implementation

String? get fontFamily;/// Color of the input in case incorrect data is entered.
@JsonKey(toJson: ColorKey.toJson, fromJson: ColorKey.fromJson) Color? get textErrorColor;