CollectBankAccountParams constructor

const CollectBankAccountParams({
  1. required CollectBankAccountPaymentMethodData paymentMethodData,
  2. @Default.new(PaymentMethodType.USBankAccount) PaymentMethodType paymentMethodType,
  3. UserInterfaceStyle? userInterfaceStyle,
  4. @JsonKey.new(includeFromJson: false, includeToJson: false) FinancialConnectionsEventHandler? onEvent,
})

Implementation

@JsonSerializable(explicitToJson: true)
const factory CollectBankAccountParams({
  /// Billingdetails of the account holder
  ///
  /// It is required to fill in the name in the billing details
  required CollectBankAccountPaymentMethodData paymentMethodData,

  /// The paymentmethod type. At this point only method [PaymentMethodType.USBankAccount]
  /// is supported.
  @Default(PaymentMethodType.USBankAccount)
  PaymentMethodType paymentMethodType,

  /// ios only. Style options for colors in Financial connections
  ///
  /// By default the bank account collector will automatically choose colors based on the
  /// user's system settings.
  UserInterfaceStyle? userInterfaceStyle,

  /// An optional event listener to receive [FinancialConnectionsEvent] for
  /// specific events during the process of a user connecting their financial accounts.
  @JsonKey(includeFromJson: false, includeToJson: false)
  FinancialConnectionsEventHandler? onEvent,
}) = _CollectBankAccountParams;