onEvent property

  1. @JsonKey.new(includeFromJson: false, includeToJson: false)
FinancialConnectionsEventHandler? get onEvent
inherited

An optional event listener to receive FinancialConnectionsEvent for specific events during the process of a user connecting their financial accounts.

Implementation

UserInterfaceStyle? get userInterfaceStyle;/// An optional event listener to receive [FinancialConnectionsEvent] for
/// specific events during the process of a user connecting their financial accounts.
@JsonKey(includeFromJson: false, includeToJson: false) FinancialConnectionsEventHandler? get onEvent;