CollectBankAccountParamsPatterns extension

Adds pattern-matching-related methods to CollectBankAccountParams.

on

Methods

map<TResult extends Object?>(TResult $default(_CollectBankAccountParams value)) → TResult

Available on CollectBankAccountParams, provided by the CollectBankAccountParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CollectBankAccountParams value)?) → TResult?

Available on CollectBankAccountParams, provided by the CollectBankAccountParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CollectBankAccountParams value)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountParams, provided by the CollectBankAccountParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(CollectBankAccountPaymentMethodData paymentMethodData, PaymentMethodType paymentMethodType, UserInterfaceStyle? userInterfaceStyle, FinancialConnectionsEventHandler? onEvent)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountParams, provided by the CollectBankAccountParamsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(CollectBankAccountPaymentMethodData paymentMethodData, PaymentMethodType paymentMethodType, UserInterfaceStyle? userInterfaceStyle, FinancialConnectionsEventHandler? onEvent)) → TResult

Available on CollectBankAccountParams, provided by the CollectBankAccountParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(CollectBankAccountPaymentMethodData paymentMethodData, PaymentMethodType paymentMethodType, UserInterfaceStyle? userInterfaceStyle, FinancialConnectionsEventHandler? onEvent)?) → TResult?

Available on CollectBankAccountParams, provided by the CollectBankAccountParamsPatterns extension

A variant of when that fallback to returning null