CollectBankAccountPaymentMethodData class abstract

Specific payment method data needed for collecting the bank account of an payment method

Available extensions
Annotations
  • @freezed

Constructors

CollectBankAccountPaymentMethodData({required BillingDetails billingDetails})
const
factory
CollectBankAccountPaymentMethodData.fromJson(Map<String, dynamic> json)
factory

Properties

billingDetails BillingDetails
no setterinherited
copyWith → $CollectBankAccountPaymentMethodDataCopyWith<CollectBankAccountPaymentMethodData>
Create a copy of CollectBankAccountPaymentMethodData with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CollectBankAccountPaymentMethodData value)) → TResult

Available on CollectBankAccountPaymentMethodData, provided by the CollectBankAccountPaymentMethodDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CollectBankAccountPaymentMethodData value)?) → TResult?

Available on CollectBankAccountPaymentMethodData, provided by the CollectBankAccountPaymentMethodDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CollectBankAccountPaymentMethodData value)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountPaymentMethodData, provided by the CollectBankAccountPaymentMethodDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(BillingDetails billingDetails)?, {required TResult orElse()}) → TResult

Available on CollectBankAccountPaymentMethodData, provided by the CollectBankAccountPaymentMethodDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CollectBankAccountPaymentMethodData to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(BillingDetails billingDetails)) → TResult

Available on CollectBankAccountPaymentMethodData, provided by the CollectBankAccountPaymentMethodDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(BillingDetails billingDetails)?) → TResult?

Available on CollectBankAccountPaymentMethodData, provided by the CollectBankAccountPaymentMethodDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited