CollectBankAccountResultPatterns extension

Adds pattern-matching-related methods to CollectBankAccountResult.

on

Methods

map<TResult extends Object?>({required TResult paymentIntent(CollectBankAccountPaymentIntentResult value), required TResult setupIntent(CollectBankAccountSetupIntentResult value)}) → TResult

Available on CollectBankAccountResult, provided by the CollectBankAccountResultPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? paymentIntent(CollectBankAccountPaymentIntentResult value)?, TResult? setupIntent(CollectBankAccountSetupIntentResult value)?}) → TResult?

Available on CollectBankAccountResult, provided by the CollectBankAccountResultPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult paymentIntent(CollectBankAccountPaymentIntentResult value)?, TResult setupIntent(CollectBankAccountSetupIntentResult value)?, required TResult orElse()}) → TResult

Available on CollectBankAccountResult, provided by the CollectBankAccountResultPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult paymentIntent(PaymentIntent paymentIntent)?, TResult setupIntent(SetupIntent setupIntent)?, required TResult orElse()}) → TResult

Available on CollectBankAccountResult, provided by the CollectBankAccountResultPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult paymentIntent(PaymentIntent paymentIntent), required TResult setupIntent(SetupIntent setupIntent)}) → TResult

Available on CollectBankAccountResult, provided by the CollectBankAccountResultPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? paymentIntent(PaymentIntent paymentIntent)?, TResult? setupIntent(SetupIntent setupIntent)?}) → TResult?

Available on CollectBankAccountResult, provided by the CollectBankAccountResultPatterns extension

A variant of when that fallback to returning null