CollectFinancialConnectionsAccountsParams constructor

const CollectFinancialConnectionsAccountsParams({
  1. UserInterfaceStyle? style,
  2. @JsonKey.new(includeFromJson: false, includeToJson: false) FinancialConnectionsEventHandler? onEvent,
  3. String? connectedAccountId,
})

Implementation

@JsonSerializable(explicitToJson: true)
const factory CollectFinancialConnectionsAccountsParams({
  /// iOS Only. Style options for colors in Financial Connections. By default, the bank account collector will automatically switch between light and dark mode compatible colors based on device settings.
  UserInterfaceStyle? style,

  /// An optional event listener to receive [FinancialConnectionsEvent] for specific events during the process of a user connecting their financial accounts.
  @JsonKey(includeFromJson: false, includeToJson: false)
  FinancialConnectionsEventHandler? onEvent,

  /// Optional connected account ID to use for this Financial Connections session. Used for Stripe Connect embedded components.
  String? connectedAccountId,
}) = _CollectFinancialConnectionsAccountsParams;