CreateGooglePayPaymentParams class abstract

Parameters to create a google pay payment.

Available extensions
Annotations
  • @freezed

Constructors

CreateGooglePayPaymentParams({required String currencyCode, required int amount})
const
factory
CreateGooglePayPaymentParams.fromJson(Map<String, dynamic> json)
factory

Properties

amount int
Amount intended to be collected.
no setterinherited
copyWith → $CreateGooglePayPaymentParamsCopyWith<CreateGooglePayPaymentParams>
Create a copy of CreateGooglePayPaymentParams with the given fields replaced by the non-null parameter values.
no setterinherited
currencyCode String
ISO 4217 alphabetic currency code.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CreateGooglePayPaymentParams value)) → TResult

Available on CreateGooglePayPaymentParams, provided by the CreateGooglePayPaymentParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CreateGooglePayPaymentParams value)?) → TResult?

Available on CreateGooglePayPaymentParams, provided by the CreateGooglePayPaymentParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CreateGooglePayPaymentParams value)?, {required TResult orElse()}) → TResult

Available on CreateGooglePayPaymentParams, provided by the CreateGooglePayPaymentParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String currencyCode, int amount)?, {required TResult orElse()}) → TResult

Available on CreateGooglePayPaymentParams, provided by the CreateGooglePayPaymentParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CreateGooglePayPaymentParams to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String currencyCode, int amount)) → TResult

Available on CreateGooglePayPaymentParams, provided by the CreateGooglePayPaymentParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String currencyCode, int amount)?) → TResult?

Available on CreateGooglePayPaymentParams, provided by the CreateGooglePayPaymentParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited