allowsRemovalOfLastSavedPaymentMethod property

bool? get allowsRemovalOfLastSavedPaymentMethod
inherited

This is an experimental feature that may be removed at any time. Defaults to true. If true, the customer can delete all saved payment methods. If false, the customer can't delete if they only have one saved payment method remaining.

Implementation

String? get merchantDisplayName;///This is an experimental feature that may be removed at any time.
/// Defaults to true. If true, the customer can delete all saved payment methods.
/// If false, the customer can't delete if they only have one saved payment method remaining.
bool? get allowsRemovalOfLastSavedPaymentMethod;