billingDetailsCollectionConfiguration property
Describes how billing details should be collected. All values default to AUTOMATIC. If NEVER is used for a required field for the Payment Method, you must provide an appropriate value as part of defaultBillingDetails.
Implementation
BillingDetails? get defaultBillingDetails;/// Describes how billing details should be collected. All values default to `AUTOMATIC`. If `NEVER` is used for a required field for the Payment Method, you must provide an appropriate value as part of `defaultBillingDetails`.
BillingDetailsCollectionConfiguration? get billingDetailsCollectionConfiguration;