headerTextForSelectionScreen property

String? get headerTextForSelectionScreen
inherited

Optional configuration for setting the header text of the Payment Method selection screen

Implementation

bool? get allowsRemovalOfLastSavedPaymentMethod;/// Optional configuration for setting the header text of the Payment Method selection screen
String? get headerTextForSelectionScreen;