preferredNetworks property

  1. @JsonKey.new(toJson: _cardBrandListToJson)
List<CardBrand>? get preferredNetworks
inherited

The list of preferred networks that should be used to process payments made with a co-branded card. This value will only be used if your user hasn't selected a network themselves.

Implementation

bool get googlePayEnabled;/// The list of preferred networks that should be used to process payments made with a co-branded card.
/// This value will only be used if your user hasn't selected a network themselves.
@JsonKey(toJson: _cardBrandListToJson) List<CardBrand>? get preferredNetworks;