setupIntentClientSecret property

String? get setupIntentClientSecret
inherited

Optional but recommended for cards, required for other payment methods. The SetupIntent client secret that will be used to confirm a new payment method. If this is missing, you will only be able to add cards without authentication steps.

Implementation

PaymentSheetAppearance? get appearance;/// Optional but recommended for cards, required for other payment methods. The SetupIntent client secret that will be used to confirm a new payment method. If this is missing, you will only be able to add cards without authentication steps.
String? get setupIntentClientSecret;