FinancialConnectionBankAccountToken class abstract

Data related to the session retrieved from the financial connection.

Available extensions
Annotations
  • @freezed

Constructors

FinancialConnectionBankAccountToken({BankAccount? bankAccount, required bool livemode, String? id, required bool used, int? created})
const
factory
FinancialConnectionBankAccountToken.fromJson(Map<String, dynamic> json)
factory

Properties

bankAccount BankAccount?
Bamkaccount details
no setterinherited
copyWith → $FinancialConnectionBankAccountTokenCopyWith<FinancialConnectionBankAccountToken>
Create a copy of FinancialConnectionBankAccountToken with the given fields replaced by the non-null parameter values.
no setterinherited
created int?
The Unix timestamp (in milliseconds) of the date this token was created
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique id for this token.
no setterinherited
livemode bool
When true the object exists in livemode and when false the object exists in test mode.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
used bool
whether or not this token has been used
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FinancialConnectionBankAccountToken value)) → TResult

Available on FinancialConnectionBankAccountToken, provided by the FinancialConnectionBankAccountTokenPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FinancialConnectionBankAccountToken value)?) → TResult?

Available on FinancialConnectionBankAccountToken, provided by the FinancialConnectionBankAccountTokenPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FinancialConnectionBankAccountToken value)?, {required TResult orElse()}) → TResult

Available on FinancialConnectionBankAccountToken, provided by the FinancialConnectionBankAccountTokenPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(BankAccount? bankAccount, bool livemode, String? id, bool used, int? created)?, {required TResult orElse()}) → TResult

Available on FinancialConnectionBankAccountToken, provided by the FinancialConnectionBankAccountTokenPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FinancialConnectionBankAccountToken to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(BankAccount? bankAccount, bool livemode, String? id, bool used, int? created)) → TResult

Available on FinancialConnectionBankAccountToken, provided by the FinancialConnectionBankAccountTokenPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(BankAccount? bankAccount, bool livemode, String? id, bool used, int? created)?) → TResult?

Available on FinancialConnectionBankAccountToken, provided by the FinancialConnectionBankAccountTokenPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited