FinancialConnectionSession class abstract

Data related to the session retrieved from the financial connection.

Available extensions
Annotations
  • @freezed

Constructors

FinancialConnectionSession({required String id, required String clientSecret, required bool livemode, required List<FinancialConnectionAccount> accounts})
const
factory
FinancialConnectionSession.fromJson(Map<String, dynamic> json)
factory

Properties

accounts List<FinancialConnectionAccount>
The accounts that were collected as part of this session
no setterinherited
clientSecret String
The client secret of the session
no setterinherited
copyWith → $FinancialConnectionSessionCopyWith<FinancialConnectionSession>
Create a copy of FinancialConnectionSession with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique id for this session
no setterinherited
livemode bool
When true the object exists in livemode and when false the object exists in test mode.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FinancialConnectionSession value)) → TResult

Available on FinancialConnectionSession, provided by the FinancialConnectionSessionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FinancialConnectionSession value)?) → TResult?

Available on FinancialConnectionSession, provided by the FinancialConnectionSessionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FinancialConnectionSession value)?, {required TResult orElse()}) → TResult

Available on FinancialConnectionSession, provided by the FinancialConnectionSessionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String clientSecret, bool livemode, List<FinancialConnectionAccount> accounts)?, {required TResult orElse()}) → TResult

Available on FinancialConnectionSession, provided by the FinancialConnectionSessionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FinancialConnectionSession to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String clientSecret, bool livemode, List<FinancialConnectionAccount> accounts)) → TResult

Available on FinancialConnectionSession, provided by the FinancialConnectionSessionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String clientSecret, bool livemode, List<FinancialConnectionAccount> accounts)?) → TResult?

Available on FinancialConnectionSession, provided by the FinancialConnectionSessionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited