FinancialConnectionsEvent class abstract

The event that occurred during the Financial Connections process.

Available extensions
Annotations
  • @freezed

Constructors

FinancialConnectionsEvent({required FinancialConnectionsEventName name, required FinancialConnectionsEventMetadata metadata})
const
factory
FinancialConnectionsEvent.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $FinancialConnectionsEventCopyWith<FinancialConnectionsEvent>
Create a copy of FinancialConnectionsEvent with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
metadata FinancialConnectionsEventMetadata
Event-associated metadata. Provides further detail related to the occurred event.
no setterinherited
name FinancialConnectionsEventName
The event's name. Represents the type of event that has occurred during the Financial Connections process.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FinancialConnectionsEvent value)) → TResult

Available on FinancialConnectionsEvent, provided by the FinancialConnectionsEventPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FinancialConnectionsEvent value)?) → TResult?

Available on FinancialConnectionsEvent, provided by the FinancialConnectionsEventPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FinancialConnectionsEvent value)?, {required TResult orElse()}) → TResult

Available on FinancialConnectionsEvent, provided by the FinancialConnectionsEventPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(FinancialConnectionsEventName name, FinancialConnectionsEventMetadata metadata)?, {required TResult orElse()}) → TResult

Available on FinancialConnectionsEvent, provided by the FinancialConnectionsEventPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FinancialConnectionsEvent to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(FinancialConnectionsEventName name, FinancialConnectionsEventMetadata metadata)) → TResult

Available on FinancialConnectionsEvent, provided by the FinancialConnectionsEventPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(FinancialConnectionsEventName name, FinancialConnectionsEventMetadata metadata)?) → TResult?

Available on FinancialConnectionsEvent, provided by the FinancialConnectionsEventPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited