manualEntry property
A Boolean value that indicates if the user completed the process through the manual entry flow.
Implementation
bool? get manualEntry;
A Boolean value that indicates if the user completed the process through the manual entry flow.
bool? get manualEntry;