GooglePayPaymentMethodParams class abstract

Payment method parameters for google pay

Available extensions
Annotations
  • @freezed

Constructors

GooglePayPaymentMethodParams({bool? existingPaymentMethodRequired, required int amount, GooglePayBillingAddressConfig? billingAddressConfig, GooglePayShippingAddressConfig? shippingAddressConfig})
const
factory
GooglePayPaymentMethodParams.fromJson(Map<String, dynamic> json)
factory

Properties

amount int
Total monetary value of the transaction. Provide this value in the currency’s smallest unit.
no setterinherited
billingAddressConfig GooglePayBillingAddressConfig?
Describes the configuration for billing address collection in the Google Pay sheet.
no setterinherited
copyWith → $GooglePayPaymentMethodParamsCopyWith<GooglePayPaymentMethodParams>
Create a copy of GooglePayPaymentMethodParams with the given fields replaced by the non-null parameter values.
no setterinherited
existingPaymentMethodRequired bool?
If true, Google Pay is considered "available" if the customer's Google Pay wallet has an existing payment method.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddressConfig GooglePayShippingAddressConfig?
Describes the configuration for shipping address collection in the Google Pay sheet.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GooglePayPaymentMethodParams value)) → TResult

Available on GooglePayPaymentMethodParams, provided by the GooglePayPaymentMethodParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GooglePayPaymentMethodParams value)?) → TResult?

Available on GooglePayPaymentMethodParams, provided by the GooglePayPaymentMethodParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GooglePayPaymentMethodParams value)?, {required TResult orElse()}) → TResult

Available on GooglePayPaymentMethodParams, provided by the GooglePayPaymentMethodParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? existingPaymentMethodRequired, int amount, GooglePayBillingAddressConfig? billingAddressConfig, GooglePayShippingAddressConfig? shippingAddressConfig)?, {required TResult orElse()}) → TResult

Available on GooglePayPaymentMethodParams, provided by the GooglePayPaymentMethodParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GooglePayPaymentMethodParams to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool? existingPaymentMethodRequired, int amount, GooglePayBillingAddressConfig? billingAddressConfig, GooglePayShippingAddressConfig? shippingAddressConfig)) → TResult

Available on GooglePayPaymentMethodParams, provided by the GooglePayPaymentMethodParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? existingPaymentMethodRequired, int amount, GooglePayBillingAddressConfig? billingAddressConfig, GooglePayShippingAddressConfig? shippingAddressConfig)?) → TResult?

Available on GooglePayPaymentMethodParams, provided by the GooglePayPaymentMethodParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited