error property

StripeException? get error
inherited

Error that occurred during the creation of the payment intent or setup intent.

Implementation

String? get clientSecret;/// Error that occurred during the creation of the payment intent or setup intent.
StripeException? get error;