IsGooglePaySupportedParams class abstract

Available extensions
Annotations
  • @freezed

Constructors

IsGooglePaySupportedParams({@Default.new(false) bool testEnv, @Default.new(false) bool existingPaymentMethodRequired, @Default.new(true) bool supportsTapToPay})
const
factory
IsGooglePaySupportedParams.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $IsGooglePaySupportedParamsCopyWith<IsGooglePaySupportedParams>
Create a copy of IsGooglePaySupportedParams with the given fields replaced by the non-null parameter values.
no setterinherited
existingPaymentMethodRequired bool
When set to true Google pay is only considered ready in case the customers google Pay wallet has an existing payment method configured.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsTapToPay bool
no setterinherited
testEnv bool
Flag to use test environment or live environment.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_IsGooglePaySupportedParams value)) → TResult

Available on IsGooglePaySupportedParams, provided by the IsGooglePaySupportedParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsGooglePaySupportedParams value)?) → TResult?

Available on IsGooglePaySupportedParams, provided by the IsGooglePaySupportedParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsGooglePaySupportedParams value)?, {required TResult orElse()}) → TResult

Available on IsGooglePaySupportedParams, provided by the IsGooglePaySupportedParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool testEnv, bool existingPaymentMethodRequired, bool supportsTapToPay)?, {required TResult orElse()}) → TResult

Available on IsGooglePaySupportedParams, provided by the IsGooglePaySupportedParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this IsGooglePaySupportedParams to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool testEnv, bool existingPaymentMethodRequired, bool supportsTapToPay)) → TResult

Available on IsGooglePaySupportedParams, provided by the IsGooglePaySupportedParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool testEnv, bool existingPaymentMethodRequired, bool supportsTapToPay)?) → TResult?

Available on IsGooglePaySupportedParams, provided by the IsGooglePaySupportedParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited