LinkDisplayParams class abstract
Parameters for Link display
- Available extensions
- Annotations
-
- @freezed
Constructors
- LinkDisplayParams({@JsonKey.new(name: 'display') required LinkDisplay linkDisplay})
-
constfactory
-
LinkDisplayParams.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $LinkDisplayParamsCopyWith<
LinkDisplayParams> -
Create a copy of LinkDisplayParams
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- linkDisplay → LinkDisplay
-
Display configuration for Link
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_LinkDisplayParams value)) → TResult -
Available on LinkDisplayParams, provided by the LinkDisplayParamsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_LinkDisplayParams value)?) → TResult? -
Available on LinkDisplayParams, provided by the LinkDisplayParamsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_LinkDisplayParams value)?, {required TResult orElse()}) → TResult -
Available on LinkDisplayParams, provided by the LinkDisplayParamsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(LinkDisplay linkDisplay)?, {required TResult orElse()}) → TResult -
Available on LinkDisplayParams, provided by the LinkDisplayParamsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this LinkDisplayParams to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(LinkDisplay linkDisplay)) → TResult -
Available on LinkDisplayParams, provided by the LinkDisplayParamsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(LinkDisplay linkDisplay)?) → TResult? -
Available on LinkDisplayParams, provided by the LinkDisplayParamsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited