Multibanco class abstract
Multibanco data associated with the payment method
- Available extensions
- Annotations
-
- @freezed
Constructors
- Multibanco({String? email, BillingDetails? billingDetails})
-
constfactory
-
Multibanco.fromJson(Map<
String, dynamic> json) -
factory
Properties
- billingDetails → BillingDetails?
-
The billing details of the customer
no setterinherited
-
copyWith
→ $MultibancoCopyWith<
Multibanco> -
Create a copy of Multibanco
with the given fields replaced by the non-null parameter values.
no setterinherited
- email → String?
-
The email of the customer
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Multibanco value)) → TResult -
Available on Multibanco, provided by the MultibancoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Multibanco value)?) → TResult? -
Available on Multibanco, provided by the MultibancoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Multibanco value)?, {required TResult orElse()}) → TResult -
Available on Multibanco, provided by the MultibancoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? email, BillingDetails? billingDetails)?, {required TResult orElse()}) → TResult -
Available on Multibanco, provided by the MultibancoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Multibanco to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? email, BillingDetails? billingDetails)) → TResult -
Available on Multibanco, provided by the MultibancoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? email, BillingDetails? billingDetails)?) → TResult? -
Available on Multibanco, provided by the MultibancoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited