PIITokenParams class abstract

Parameters that are used to create a token for a personally identifiable information (PII).

Available extensions
Annotations
  • @freezed

Constructors

PIITokenParams({@Default.new(TokenType.Pii) TokenType type, required String personalId})
const
factory
PIITokenParams.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PIITokenParamsCopyWith<PIITokenParams>
Create a copy of PIITokenParams with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
personalId String
The user's personal ID number
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TokenType
Type of token.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PIITokenParams value)) → TResult

Available on PIITokenParams, provided by the PIITokenParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PIITokenParams value)?) → TResult?

Available on PIITokenParams, provided by the PIITokenParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PIITokenParams value)?, {required TResult orElse()}) → TResult

Available on PIITokenParams, provided by the PIITokenParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(TokenType type, String personalId)?, {required TResult orElse()}) → TResult

Available on PIITokenParams, provided by the PIITokenParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PIITokenParams to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(TokenType type, String personalId)) → TResult

Available on PIITokenParams, provided by the PIITokenParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(TokenType type, String personalId)?) → TResult?

Available on PIITokenParams, provided by the PIITokenParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited