amount property
Amount that will be collected in the payment intent.
Implementation
String get id;/// Amount that will be collected in the payment intent.
num get amount;
Amount that will be collected in the payment intent.
String get id;/// Amount that will be collected in the payment intent.
num get amount;