captureMethod property

CaptureMethod get captureMethod
inherited

How the funds will be caputure from the customer's account.

Implementation

bool get livemode;/// How the funds will be caputure from the customer's account.
CaptureMethod get captureMethod;