clientSecret property
The client is secret is used for handling the payment from the Client side.
Implementation
PaymentIntentsStatus get status;/// The client is secret is used for handling the payment from the Client side.
String get clientSecret;
The client is secret is used for handling the payment from the Client side.
PaymentIntentsStatus get status;/// The client is secret is used for handling the payment from the Client side.
String get clientSecret;