receiptEmail property

String? get receiptEmail
inherited

Email address where the receipt will be send to.

Implementation

String? get description;/// Email address where the receipt will be send to.
String? get receiptEmail;