customerId property

String? get customerId
inherited

Id related to the customer to which this paymentmethod has been saved.

Implementation

@JsonKey(name: 'Multibanco') Multibanco? get multibanco;/// Id related to the customer to which this paymentmethod has been saved.
 String? get customerId;