usBankAccount property

  1. @JsonKey.new(name: 'USBankAccount')
UsBankAccount get usBankAccount
inherited

Containing additional data in case paymentmethod type is Us bank account.

Implementation

@JsonKey(name: 'Fpx') Fpx get fpx;/// Containing additional data in case paymentmethod type is Us bank account.
@JsonKey(name: 'USBankAccount') UsBankAccount get usBankAccount;