PaymentSheetAppearance class abstract

Parameters that change the appearance of the payment sheet.

Available extensions
Annotations
  • @freezed

Constructors

PaymentSheetAppearance({PaymentSheetAppearanceColors? colors, PaymentSheetShape? shapes, PaymentSheetPrimaryButtonAppearance? primaryButton, EmbeddedPaymentElementAppearance? embeddedPaymentElement, EdgeInsetsConfig? formInsetValues, bool? applyLiquidGlass, NavigationBarStyle? navigationBarStyle})
const
factory
PaymentSheetAppearance.fromJson(Map<String, dynamic> json)
factory

Properties

applyLiquidGlass bool?
Setting this boolean to true will call the iOS applyLiquidGlass() method (https://stripe.dev/stripe-ios/stripepaymentsheet/documentation/stripepaymentsheet/paymentsheet/appearance/applyliquidglass()) on the Appearance object prior to applying other appearance customizations set on AppearanceParams. Requires iOS26 and Xcode 26, and will be ignored if these requirements are not met. @default false
no setterinherited
colors PaymentSheetAppearanceColors?
Color parameters
no setterinherited
copyWith → $PaymentSheetAppearanceCopyWith<PaymentSheetAppearance>
Create a copy of PaymentSheetAppearance with the given fields replaced by the non-null parameter values.
no setterinherited
embeddedPaymentElement EmbeddedPaymentElementAppearance?
Describes the appearance of the Embedded Mobile Payment Element
no setterinherited
formInsetValues EdgeInsetsConfig?
Describes the inset values applied to Mobile Payment Element forms
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
Describes the navigation bar style (iOS only)
no setterinherited
primaryButton PaymentSheetPrimaryButtonAppearance?
PaymentSheet appearance
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shapes PaymentSheetShape?
Shapes parameters
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PaymentSheetAppearance value)) → TResult

Available on PaymentSheetAppearance, provided by the PaymentSheetAppearancePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PaymentSheetAppearance value)?) → TResult?

Available on PaymentSheetAppearance, provided by the PaymentSheetAppearancePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PaymentSheetAppearance value)?, {required TResult orElse()}) → TResult

Available on PaymentSheetAppearance, provided by the PaymentSheetAppearancePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(PaymentSheetAppearanceColors? colors, PaymentSheetShape? shapes, PaymentSheetPrimaryButtonAppearance? primaryButton, EmbeddedPaymentElementAppearance? embeddedPaymentElement, EdgeInsetsConfig? formInsetValues, bool? applyLiquidGlass, NavigationBarStyle? navigationBarStyle)?, {required TResult orElse()}) → TResult

Available on PaymentSheetAppearance, provided by the PaymentSheetAppearancePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PaymentSheetAppearance to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(PaymentSheetAppearanceColors? colors, PaymentSheetShape? shapes, PaymentSheetPrimaryButtonAppearance? primaryButton, EmbeddedPaymentElementAppearance? embeddedPaymentElement, EdgeInsetsConfig? formInsetValues, bool? applyLiquidGlass, NavigationBarStyle? navigationBarStyle)) → TResult

Available on PaymentSheetAppearance, provided by the PaymentSheetAppearancePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(PaymentSheetAppearanceColors? colors, PaymentSheetShape? shapes, PaymentSheetPrimaryButtonAppearance? primaryButton, EmbeddedPaymentElementAppearance? embeddedPaymentElement, EdgeInsetsConfig? formInsetValues, bool? applyLiquidGlass, NavigationBarStyle? navigationBarStyle)?) → TResult?

Available on PaymentSheetAppearance, provided by the PaymentSheetAppearancePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited