PaymentSheetApplePay class abstract

Parameters related to the Payment sheet Apple Pay config.

Available extensions
Annotations
  • @freezed

Constructors

PaymentSheetApplePay({required String merchantCountryCode, List<ApplePayCartSummaryItem>? cartItems, PlatformButtonType? buttonType, PaymentRequestType? request, @JsonKey.new(includeFromJson: false, includeToJson: false) OnOrderTracking? setOrderTracking})
const
factory
PaymentSheetApplePay.fromJson(Map<String, dynamic> json)
factory

Properties

buttonType PlatformButtonType?
Sets the the text displayed by the call to action button in the apple pay sheet.
no setterinherited
cartItems List<ApplePayCartSummaryItem>?
An array of CartSummaryItem item objects that summarize the amount of the payment. If you're using a SetupIntent for a recurring payment, you should set this to display the amount you intend to charge.
no setterinherited
copyWith → $PaymentSheetApplePayCopyWith<PaymentSheetApplePay>
Create a copy of PaymentSheetApplePay with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
merchantCountryCode String
The two-letter ISO 3166 code of the country of your business, e.g. "US"
no setterinherited
request PaymentRequestType?
Use this for a different payment request than a one time request.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setOrderTracking OnOrderTracking?
Callback function for setting the order details (retrieved from your server) to give users the ability to track and manage their purchases in Wallet. Stripe calls your implementation after the payment is complete, but before iOS dismisses the Apple Pay sheet. You must call the completion function, or else the Apple Pay sheet will hang.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PaymentSheetApplePay value)) → TResult

Available on PaymentSheetApplePay, provided by the PaymentSheetApplePayPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PaymentSheetApplePay value)?) → TResult?

Available on PaymentSheetApplePay, provided by the PaymentSheetApplePayPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PaymentSheetApplePay value)?, {required TResult orElse()}) → TResult

Available on PaymentSheetApplePay, provided by the PaymentSheetApplePayPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String merchantCountryCode, List<ApplePayCartSummaryItem>? cartItems, PlatformButtonType? buttonType, PaymentRequestType? request, OnOrderTracking? setOrderTracking)?, {required TResult orElse()}) → TResult

Available on PaymentSheetApplePay, provided by the PaymentSheetApplePayPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PaymentSheetApplePay to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String merchantCountryCode, List<ApplePayCartSummaryItem>? cartItems, PlatformButtonType? buttonType, PaymentRequestType? request, OnOrderTracking? setOrderTracking)) → TResult

Available on PaymentSheetApplePay, provided by the PaymentSheetApplePayPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String merchantCountryCode, List<ApplePayCartSummaryItem>? cartItems, PlatformButtonType? buttonType, PaymentRequestType? request, OnOrderTracking? setOrderTracking)?) → TResult?

Available on PaymentSheetApplePay, provided by the PaymentSheetApplePayPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited