PlatformButtonType enum
Determine the style for the platform button
Values
- plain → const PlatformButtonType
-
A button with the Apple Pay or Google pay logo only.
Use this button when an additional call to action isn't needed.
const PlatformButtonType(0) - buy → const PlatformButtonType
-
A button for product purchases.
const PlatformButtonType(1) - setUp → const PlatformButtonType
-
iOS only, button useful for promping the user to set up a card.
const PlatformButtonType(2) - inStore → const PlatformButtonType
-
iOS only button useful for paying bills or invoices
const PlatformButtonType(3) - donate → const PlatformButtonType
-
Button used by approved non profit organisations.
const PlatformButtonType(4) - checkout → const PlatformButtonType
-
Button useful for purchase experiences that include other payment buttons that start with checkout.
const PlatformButtonType(5) - book → const PlatformButtonType
-
Button useful for booking trips, flights etc.
const PlatformButtonType(6) - subscribe → const PlatformButtonType
-
Button useful for purchasing a supscription to a service.
const PlatformButtonType(7) - reload → const PlatformButtonType
-
iOS only, button useful for adding money to a card account or payment system.
const PlatformButtonType(8) - addMoney → const PlatformButtonType
-
iOS only, button usefulfor adding money to a card account or payment system.
const PlatformButtonType(9) - topUp → const PlatformButtonType
-
iOS only, button usefulfor adding money to a card account or payment system.
const PlatformButtonType(10) - order → const PlatformButtonType
-
Button useful for placing orders.
const PlatformButtonType(11) - rent → const PlatformButtonType
-
iOS only, button useful for reting items: e.g. cards or scooters.
const PlatformButtonType(12) - support → const PlatformButtonType
-
iOS only, button useful to help people give money to projects, causes and organisations.
const PlatformButtonType(13) - contribute → const PlatformButtonType
-
iOS only, button useful to help people contribute money to projects, causes and organisations.
const PlatformButtonType(14) - tip → const PlatformButtonType
-
iOS only, button useful for letting people tip for goods or services.
const PlatformButtonType(15) - advance → const PlatformButtonType
-
iOS only, button useful for generic purchases.
const PlatformButtonType(16) - pay → const PlatformButtonType
-
Android only, button useful for generic payments.
const PlatformButtonType(1000) - googlePayMark → const PlatformButtonType
-
Android only, button with Google Pay logo.
Use when you only show Google Pay as only option in payment flow.
const PlatformButtonType(1001)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PlatformButtonType> - A constant List of the values in this enum, in order of their declaration.