PlatformPayConfirmParams class abstract

Available extensions
Annotations
  • @freezed

Constructors

PlatformPayConfirmParams.applePay({required ApplePayParams applePay})
const
factory
PlatformPayConfirmParams.fromJson(Map<String, dynamic> json)
factory
PlatformPayConfirmParams.googlePay({required GooglePayParams googlePay})
const
factory
PlatformPayConfirmParams.web({required PlatformPayWebPaymentRequestCreateOptions options})
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult googlePay(PlatformPayConfirmParamsGooglePay value), required TResult applePay(PlatformPayConfirmParamsApplePay value), required TResult web(PlatformPayConfirmParamsWeb value)}) → TResult

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? googlePay(PlatformPayConfirmParamsGooglePay value)?, TResult? applePay(PlatformPayConfirmParamsApplePay value)?, TResult? web(PlatformPayConfirmParamsWeb value)?}) → TResult?

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult googlePay(PlatformPayConfirmParamsGooglePay value)?, TResult applePay(PlatformPayConfirmParamsApplePay value)?, TResult web(PlatformPayConfirmParamsWeb value)?, required TResult orElse()}) → TResult

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult googlePay(GooglePayParams googlePay)?, TResult applePay(ApplePayParams applePay)?, TResult web(PlatformPayWebPaymentRequestCreateOptions options)?, required TResult orElse()}) → TResult

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PlatformPayConfirmParams to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult googlePay(GooglePayParams googlePay), required TResult applePay(ApplePayParams applePay), required TResult web(PlatformPayWebPaymentRequestCreateOptions options)}) → TResult

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? googlePay(GooglePayParams googlePay)?, TResult? applePay(ApplePayParams applePay)?, TResult? web(PlatformPayWebPaymentRequestCreateOptions options)?}) → TResult?

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited