PlatformPayConfirmParamsPatterns extension

Adds pattern-matching-related methods to PlatformPayConfirmParams.

on

Methods

map<TResult extends Object?>({required TResult googlePay(PlatformPayConfirmParamsGooglePay value), required TResult applePay(PlatformPayConfirmParamsApplePay value), required TResult web(PlatformPayConfirmParamsWeb value)}) → TResult

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? googlePay(PlatformPayConfirmParamsGooglePay value)?, TResult? applePay(PlatformPayConfirmParamsApplePay value)?, TResult? web(PlatformPayConfirmParamsWeb value)?}) → TResult?

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult googlePay(PlatformPayConfirmParamsGooglePay value)?, TResult applePay(PlatformPayConfirmParamsApplePay value)?, TResult web(PlatformPayConfirmParamsWeb value)?, required TResult orElse()}) → TResult

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult googlePay(GooglePayParams googlePay)?, TResult applePay(ApplePayParams applePay)?, TResult web(PlatformPayWebPaymentRequestCreateOptions options)?, required TResult orElse()}) → TResult

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult googlePay(GooglePayParams googlePay), required TResult applePay(ApplePayParams applePay), required TResult web(PlatformPayWebPaymentRequestCreateOptions options)}) → TResult

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? googlePay(GooglePayParams googlePay)?, TResult? applePay(ApplePayParams applePay)?, TResult? web(PlatformPayWebPaymentRequestCreateOptions options)?}) → TResult?

Available on PlatformPayConfirmParams, provided by the PlatformPayConfirmParamsPatterns extension

A variant of when that fallback to returning null