PlatformPayPaymentMethod class abstract

Result object when creating a payment method through apple pay or google pay.

Available extensions
Annotations
  • @freezed

Constructors

PlatformPayPaymentMethod({required PaymentMethod paymentMethod, PlatformPayShippingContact? shippingContact})
const
factory
PlatformPayPaymentMethod.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PlatformPayPaymentMethodCopyWith<PlatformPayPaymentMethod>
Create a copy of PlatformPayPaymentMethod with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
paymentMethod PaymentMethod
The payment method
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingContact PlatformPayShippingContact?
shipping contact of the user
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PlatformPayPaymentMethod value)) → TResult

Available on PlatformPayPaymentMethod, provided by the PlatformPayPaymentMethodPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PlatformPayPaymentMethod value)?) → TResult?

Available on PlatformPayPaymentMethod, provided by the PlatformPayPaymentMethodPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PlatformPayPaymentMethod value)?, {required TResult orElse()}) → TResult

Available on PlatformPayPaymentMethod, provided by the PlatformPayPaymentMethodPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(PaymentMethod paymentMethod, PlatformPayShippingContact? shippingContact)?, {required TResult orElse()}) → TResult

Available on PlatformPayPaymentMethod, provided by the PlatformPayPaymentMethodPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PlatformPayPaymentMethod to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(PaymentMethod paymentMethod, PlatformPayShippingContact? shippingContact)) → TResult

Available on PlatformPayPaymentMethod, provided by the PlatformPayPaymentMethodPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(PaymentMethod paymentMethod, PlatformPayShippingContact? shippingContact)?) → TResult?

Available on PlatformPayPaymentMethod, provided by the PlatformPayPaymentMethodPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited