PlatformPayPaymentMethodParams class sealed

Available extensions
Annotations
  • @freezed

Constructors

PlatformPayPaymentMethodParams.applePay({required ApplePayParams applePayParams})
const
factory
PlatformPayPaymentMethodParams.googlePay({required GooglePayParams googlePayParams, required GooglePayPaymentMethodParams googlePayPaymentMethodParams})
const
factory
PlatformPayPaymentMethodParams.web({required PlatformPayWebPaymentRequestCreateOptions options})
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult googlePay(PlatformPayPaymentMethodParamsGooglePay value), required TResult applePay(PlatformPayPaymentMethodParamsApplePay value), required TResult web(PlatformPayPaymentMethodParamsWeb value)}) → TResult

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? googlePay(PlatformPayPaymentMethodParamsGooglePay value)?, TResult? applePay(PlatformPayPaymentMethodParamsApplePay value)?, TResult? web(PlatformPayPaymentMethodParamsWeb value)?}) → TResult?

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult googlePay(PlatformPayPaymentMethodParamsGooglePay value)?, TResult applePay(PlatformPayPaymentMethodParamsApplePay value)?, TResult web(PlatformPayPaymentMethodParamsWeb value)?, required TResult orElse()}) → TResult

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult googlePay(GooglePayParams googlePayParams, GooglePayPaymentMethodParams googlePayPaymentMethodParams)?, TResult applePay(ApplePayParams applePayParams)?, TResult web(PlatformPayWebPaymentRequestCreateOptions options)?, required TResult orElse()}) → TResult

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult googlePay(GooglePayParams googlePayParams, GooglePayPaymentMethodParams googlePayPaymentMethodParams), required TResult applePay(ApplePayParams applePayParams), required TResult web(PlatformPayWebPaymentRequestCreateOptions options)}) → TResult

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? googlePay(GooglePayParams googlePayParams, GooglePayPaymentMethodParams googlePayPaymentMethodParams)?, TResult? applePay(ApplePayParams applePayParams)?, TResult? web(PlatformPayWebPaymentRequestCreateOptions options)?}) → TResult?

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited