PlatformPayPaymentMethodParamsPatterns extension

Adds pattern-matching-related methods to PlatformPayPaymentMethodParams.

on

Methods

map<TResult extends Object?>({required TResult googlePay(PlatformPayPaymentMethodParamsGooglePay value), required TResult applePay(PlatformPayPaymentMethodParamsApplePay value), required TResult web(PlatformPayPaymentMethodParamsWeb value)}) → TResult

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? googlePay(PlatformPayPaymentMethodParamsGooglePay value)?, TResult? applePay(PlatformPayPaymentMethodParamsApplePay value)?, TResult? web(PlatformPayPaymentMethodParamsWeb value)?}) → TResult?

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult googlePay(PlatformPayPaymentMethodParamsGooglePay value)?, TResult applePay(PlatformPayPaymentMethodParamsApplePay value)?, TResult web(PlatformPayPaymentMethodParamsWeb value)?, required TResult orElse()}) → TResult

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult googlePay(GooglePayParams googlePayParams, GooglePayPaymentMethodParams googlePayPaymentMethodParams)?, TResult applePay(ApplePayParams applePayParams)?, TResult web(PlatformPayWebPaymentRequestCreateOptions options)?, required TResult orElse()}) → TResult

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult googlePay(GooglePayParams googlePayParams, GooglePayPaymentMethodParams googlePayPaymentMethodParams), required TResult applePay(ApplePayParams applePayParams), required TResult web(PlatformPayWebPaymentRequestCreateOptions options)}) → TResult

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? googlePay(GooglePayParams googlePayParams, GooglePayPaymentMethodParams googlePayPaymentMethodParams)?, TResult? applePay(ApplePayParams applePayParams)?, TResult? web(PlatformPayWebPaymentRequestCreateOptions options)?}) → TResult?

Available on PlatformPayPaymentMethodParams, provided by the PlatformPayPaymentMethodParamsPatterns extension

A variant of when that fallback to returning null