errors property
In case user input is wrong use this to display the errors in the apple pay sheet.
Implementation
List<ApplePayShippingMethod> get shippingMethods;/// In case user input is wrong use this to display the errors in the apple pay sheet.
List<ApplePaySheetError>? get errors;