PlatformPayWebPaymentItem class abstract

Available extensions
Annotations
  • @freezed

Constructors

PlatformPayWebPaymentItem({required num amount, required String label, @Default.new(false) bool pending})
const
factory
PlatformPayWebPaymentItem.fromJson(Map<String, dynamic> json)
factory

Properties

amount num
The amount in the currency's subunit (e.g. cents, yen, etc.)
no setterinherited
copyWith → $PlatformPayWebPaymentItemCopyWith<PlatformPayWebPaymentItem>
Create a copy of PlatformPayWebPaymentItem with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
label String
A name that the browser shows the customer in the payment interface.
no setterinherited
pending bool
If you might change this amount later (for example, after you have calculated shipping costs), set this to true. Note that browsers treat this as a hint for how to display things, and not necessarily as something that will prevent submission.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_$PaymentItem value)) → TResult

Available on PlatformPayWebPaymentItem, provided by the PlatformPayWebPaymentItemPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_$PaymentItem value)?) → TResult?

Available on PlatformPayWebPaymentItem, provided by the PlatformPayWebPaymentItemPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_$PaymentItem value)?, {required TResult orElse()}) → TResult

Available on PlatformPayWebPaymentItem, provided by the PlatformPayWebPaymentItemPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(num amount, String label, bool pending)?, {required TResult orElse()}) → TResult

Available on PlatformPayWebPaymentItem, provided by the PlatformPayWebPaymentItemPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PlatformPayWebPaymentItem to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(num amount, String label, bool pending)) → TResult

Available on PlatformPayWebPaymentItem, provided by the PlatformPayWebPaymentItemPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(num amount, String label, bool pending)?) → TResult?

Available on PlatformPayWebPaymentItem, provided by the PlatformPayWebPaymentItemPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited