label property

String get label
inherited

A name that the browser shows the customer in the payment interface.

Implementation

num get amount;/// A name that the browser shows the customer in the payment interface.
String get label;