pending property

bool get pending
inherited

If you might change this amount later (for example, after you have calculated shipping costs), set this to true. Note that browsers treat this as a hint for how to display things, and not necessarily as something that will prevent submission.

Implementation

String get label;/// If you might change this amount later (for example, after you have calculated shipping costs), set this to true.
/// Note that browsers treat this as a hint for how to display things, and not necessarily as something that will
/// prevent submission.
bool get pending;