displayItems property
An array of PaymentItem objects. These objects are shown as line items in the browser’s payment interface. Note that the sum of the line item amounts does not need to add up to the total amount above.
Implementation
PlatformPayWebPaymentItem get total;/// An array of PaymentItem objects. These objects are shown as line items in the browser’s payment interface.
/// Note that the sum of the line item amounts does not need to add up to the total amount above.
List<PlatformPayWebPaymentItem> get displayItems;