requestPayerName property

bool get requestPayerName
inherited

By default, the browser‘s payment interface only asks the customer for actual payment information. A customer name can be collected by setting this option to true. This collected name will appears in the PaymentResponse object.

We highly recommend you collect name as this also results in collection of billing address for Apple Pay. The billing address can be used to perform address verification and block fraudulent payments. For all other payment methods, the billing address is automatically collected when available.

Implementation

List<PlatformPayWebPaymentItem> get displayItems;/// By default, the browser‘s payment interface only asks the customer for actual payment information. A customer
/// name can be collected by setting this option to true. This collected name will appears in the PaymentResponse object.
///
///  We highly recommend you collect name as this also results in collection of billing address for Apple Pay.
///  The billing address can be used to perform address verification and block fraudulent payments.
///  For all other payment methods, the billing address is automatically collected when available.
bool get requestPayerName;