total property

PlatformPayWebPaymentItem get total
inherited

A PaymentItem object. This PaymentItem is shown to the customer in the browser’s payment interface.

Implementation

String get currency;/// A PaymentItem object. This PaymentItem is shown to the customer in the browser’s payment interface.
PlatformPayWebPaymentItem get total;