PlatformPayWebPaymentRequestCreateOptionsPatterns extension

Adds pattern-matching-related methods to PlatformPayWebPaymentRequestCreateOptions.

on

Methods

map<TResult extends Object?>(TResult $default(_PaymentRequestCreateOptions value)) → TResult

Available on PlatformPayWebPaymentRequestCreateOptions, provided by the PlatformPayWebPaymentRequestCreateOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PaymentRequestCreateOptions value)?) → TResult?

Available on PlatformPayWebPaymentRequestCreateOptions, provided by the PlatformPayWebPaymentRequestCreateOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PaymentRequestCreateOptions value)?, {required TResult orElse()}) → TResult

Available on PlatformPayWebPaymentRequestCreateOptions, provided by the PlatformPayWebPaymentRequestCreateOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String country, String currency, PlatformPayWebPaymentItem total, List<PlatformPayWebPaymentItem> displayItems, bool requestPayerName, bool requestPayerEmail, bool requestPayerPhone, bool requestShipping, List<PlatformPayWebShippingOption> shippingOptions, List<PlatformPayWebWalletType> disableWallets)?, {required TResult orElse()}) → TResult

Available on PlatformPayWebPaymentRequestCreateOptions, provided by the PlatformPayWebPaymentRequestCreateOptionsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String country, String currency, PlatformPayWebPaymentItem total, List<PlatformPayWebPaymentItem> displayItems, bool requestPayerName, bool requestPayerEmail, bool requestPayerPhone, bool requestShipping, List<PlatformPayWebShippingOption> shippingOptions, List<PlatformPayWebWalletType> disableWallets)) → TResult

Available on PlatformPayWebPaymentRequestCreateOptions, provided by the PlatformPayWebPaymentRequestCreateOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String country, String currency, PlatformPayWebPaymentItem total, List<PlatformPayWebPaymentItem> displayItems, bool requestPayerName, bool requestPayerEmail, bool requestPayerPhone, bool requestShipping, List<PlatformPayWebShippingOption> shippingOptions, List<PlatformPayWebWalletType> disableWallets)?) → TResult?

Available on PlatformPayWebPaymentRequestCreateOptions, provided by the PlatformPayWebPaymentRequestCreateOptionsPatterns extension

A variant of when that fallback to returning null