forSetupIntent property

bool get forSetupIntent
inherited

Determines whether to present Google Pay in order to confirm a SetupIntent or a PaymentIntent.

Implementation

String get clientSecret;/// Determines whether to present Google Pay in order to confirm a [SetupIntent]
/// or a [PaymentIntent].
bool get forSetupIntent;