clientSecret property

String get clientSecret
inherited

The client is secret is used for handling the payment from the Client side.

Implementation

bool get livemode;/// The client is secret is used for handling the payment from the Client side.
String get clientSecret;