created property

String? get created
inherited

Timestamp since epoch that represents the time the intent is created.

Implementation

String? get description;/// Timestamp since epoch that represents the time the intent is created.
String? get created;