paymentMethodId property
Id of the payment method used in this intent.
Implementation
String get clientSecret;/// Id of the payment method used in this intent.
String get paymentMethodId;
Id of the payment method used in this intent.
String get clientSecret;/// Id of the payment method used in this intent.
String get paymentMethodId;