paymentMethodTypes property

List<PaymentMethodType> get paymentMethodTypes
inherited

List of payment method types associated with this intent.

Implementation

String get usage;/// List of payment method types associated with this intent.
List<PaymentMethodType> get paymentMethodTypes;