usage property

String get usage
inherited

Indicates how the intent is used in the future.

Implementation

String get paymentMethodId;/// Indicates how the intent is used in the future.
String get usage;