allowsRemovalOfLastSavedPaymentMethod property
This is an experimental feature that may be removed at any time. Defaults to true. If true, the customer can delete all saved payment methods. If false, the customer can't delete if they only have one saved payment method remaining.
Implementation
@JsonKey(name: 'defaultBillingDetails') BillingDetails? get billingDetails;///This is an experimental feature that may be removed at any time.
/// Defaults to true. If true, the customer can delete all saved payment methods.
/// If false, the customer can't delete if they only have one saved payment method remaining.
bool? get allowsRemovalOfLastSavedPaymentMethod;