billingDetails property

  1. @JsonKey.new(name: 'defaultBillingDetails')
BillingDetails? get billingDetails
inherited

Default billing information of the customer.

Use this field to already prefill the customers billingDetails in the payment sheet. For example when you supply a country the country will be set on the payment sheet + alternative localization options. This does not set the billingDetails on the paymentIntent since the customer can change those.

Implementation

PaymentSheetAppearance? get appearance;/// Default billing information of the customer.
///
/// Use this field to already prefill the customers billingDetails in the payment sheet.
/// For example when you supply a country the country will be set on the payment sheet +
/// alternative localization options. This does not set the billingDetails on the
/// paymentIntent since the customer can change those.
@JsonKey(name: 'defaultBillingDetails') BillingDetails? get billingDetails;