cardFundingFiltering property
Configuration for filtering cards by funding type. @note This is a private preview API and will have no effect unless your Stripe account is enrolled in the private preview.
Implementation
CardBrandAcceptance? get cardBrandAcceptance;///
///Configuration for filtering cards by funding type.
/// @note This is a private preview API and will have no effect unless your Stripe account is enrolled in the private preview.
///
CardFundingFiltering? get cardFundingFiltering;