intentConfiguration property

IntentConfiguration? get intentConfiguration
inherited

Use this when you want to collect payment information before creating a setupintent or payment intent.

Implementation

String? get setupIntentClientSecret;/// Use this when you want to collect payment information before creating a
/// setupintent or payment intent.
IntentConfiguration? get intentConfiguration;