opensCardScannerAutomatically property

bool? get opensCardScannerAutomatically
inherited

By default, PaymentSheet offers a card scan button within the new card entry form. When opensCardScannerAutomatically is set to true, the card entry form will initialize with the card scanner already open. Defaults to false.

Implementation

CustomPaymentMethodConfiguration? get customPaymentMethodConfiguration;///By default, PaymentSheet offers a card scan button within the new card entry form.
/// When opensCardScannerAutomatically is set to true,
/// the card entry form will initialize with the card scanner already open.
/// Defaults to false.
bool? get opensCardScannerAutomatically;