paymentIntentClientSecret property

String? get paymentIntentClientSecret
inherited

Secret used for client-side retrieval using a publishable key.

If this value is null make sure to add a setupIntentClientSecret

Implementation

String? get customerSessionClientSecret;/// Secret used for client-side retrieval using a publishable key.
///
/// If this value is null make sure to add a [setupIntentClientSecret]
String? get paymentIntentClientSecret;