removeSavedPaymentMethodMessage property

String? get removeSavedPaymentMethodMessage
inherited

Optional configuration to display a custom message when a saved payment method is removed. iOS only.

Implementation

BillingDetailsCollectionConfiguration? get billingDetailsCollectionConfiguration;///  Optional configuration to display a custom message when a saved payment method is removed. iOS only.
String? get removeSavedPaymentMethodMessage;