configurePlatformOrderTracking method

Future<void> configurePlatformOrderTracking({
  1. required PlatformPayOrderDetails orderDetails,
})

Updates the native payment sheet with new order tracking information **iOS-only.

This method is required to call when the onOrderTracking is called

Implementation

Future<void> configurePlatformOrderTracking({
  required PlatformPayOrderDetails orderDetails,
}) async {
  await _awaitForSettings();
  assert(() {
    debugConfigurePlatformOrderTrackingCalled = true;
    return true;
  }());
  return _platform.configurePlatformOrderTracking(orderDetails: orderDetails);
}