resetPaymentSheetCustomer method

Future<void> resetPaymentSheetCustomer()

Call this method when the user logs out from your app.

This will ensure that any persisted authentication state in the paymentsheet, such as authentication cookies are cleared during logout.

Implementation

Future<void> resetPaymentSheetCustomer() async {
  await _awaitForSettings();
  return await _platform.resetPaymentSheetCustomer();
}