updatePlatformSheet method

Future<void> updatePlatformSheet({
  1. required PlatformPaySheetUpdateParams params,
})

Updates the native payment sheet with new data **iOS-only.

For example this method is required to call when the user updates shippingmethod, shippingAddress and couponcode.

Implementation

Future<void> updatePlatformSheet({
  required PlatformPaySheetUpdateParams params,
}) async {
  await _awaitForSettings();
  assert(() {
    debugUpdatePlatformSheetCalled = true;
    return true;
  }());
  debugUpdatePlatformSheetCalled = true;
  return _platform.updatePlatformSheet(params: params);
}