verifyPaymentIntentWithMicrodeposits method

Future<CollectBankAccountResult> verifyPaymentIntentWithMicrodeposits({
  1. required bool isPaymentIntent,
  2. required String clientSecret,
  3. required VerifyMicroDepositsParams params,
})

Verify the bank account with microtransactions

Only US bank accounts are supported.This method is only implemented for iOS at the moment. The returned CollectBankAccountResult is a sealed union containing either a PaymentIntent or a SetupIntent depending on isPaymentIntent.

Implementation

Future<CollectBankAccountResult> verifyPaymentIntentWithMicrodeposits({
  /// Whether the clientsecret is associated with setup or paymentintent
  required bool isPaymentIntent,

  /// The clientSecret of the payment and setup intent
  required String clientSecret,

  /// Parameters to verify the microdeposits.
  required VerifyMicroDepositsParams params,
}) async {
  return await _platform.verifyPaymentIntentWithMicrodeposits(
    isPaymentIntent: isPaymentIntent,
    clientSecret: clientSecret,
    params: params,
  );
}