StripeError<T> class abstract

Wrapper class that represents an error with the Stripe platform.

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

StripeError({@Default.new('Unknown error') String message, @JsonKey.new(fromJson: _dataFromJson, toJson: _dataToJson) required T code})
const
factory
StripeError.fromJson(Map<String, dynamic> json)
factory

Properties

code → T
no setterinherited
copyWith → $StripeErrorCopyWith<T, StripeError<T>>
Create a copy of StripeError with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
message String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_StripeErrorGeneric<T> value)) → TResult

Available on StripeError<T>, provided by the StripeErrorPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_StripeErrorGeneric<T> value)?) → TResult?

Available on StripeError<T>, provided by the StripeErrorPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_StripeErrorGeneric<T> value)?, {required TResult orElse()}) → TResult

Available on StripeError<T>, provided by the StripeErrorPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String message, T code)?, {required TResult orElse()}) → TResult

Available on StripeError<T>, provided by the StripeErrorPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this StripeError to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String message, T code)) → TResult

Available on StripeError<T>, provided by the StripeErrorPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String message, T code)?) → TResult?

Available on StripeError<T>, provided by the StripeErrorPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited