StripeException class abstract
Exception retrieved from the Stripe platform.
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
- StripeException({required LocalizedErrorMessage error})
-
constfactory
-
StripeException.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $StripeExceptionCopyWith<
StripeException> -
Create a copy of StripeException
with the given fields replaced by the non-null parameter values.
no setterinherited
- error → LocalizedErrorMessage
-
error details
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_StripeException value)) → TResult -
Available on StripeException, provided by the StripeExceptionPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_StripeException value)?) → TResult? -
Available on StripeException, provided by the StripeExceptionPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_StripeException value)?, {required TResult orElse()}) → TResult -
Available on StripeException, provided by the StripeExceptionPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(LocalizedErrorMessage error)?, {required TResult orElse()}) → TResult -
Available on StripeException, provided by the StripeExceptionPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this StripeException to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(LocalizedErrorMessage error)) → TResult -
Available on StripeException, provided by the StripeExceptionPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(LocalizedErrorMessage error)?) → TResult? -
Available on StripeException, provided by the StripeExceptionPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited