ThreeDSecureButtonThemeData class abstract

Styling info related to the 3d secure button.

Available extensions
Annotations
  • @freezed

Constructors

ThreeDSecureButtonThemeData({String? backgroundColor, double? cornerRadius, String? textColor, double? textFontSize})
const
factory
ThreeDSecureButtonThemeData.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor String?
Color in hex for button background
no setterinherited
copyWith → $ThreeDSecureButtonThemeDataCopyWith<ThreeDSecureButtonThemeData>
Create a copy of ThreeDSecureButtonThemeData with the given fields replaced by the non-null parameter values.
no setterinherited
cornerRadius double?
Button corner radius.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor String?
Color in hex for button text.
no setterinherited
textFontSize double?
Font size for the button text.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ThreeDSecureButtonThemeData value)) → TResult

Available on ThreeDSecureButtonThemeData, provided by the ThreeDSecureButtonThemeDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ThreeDSecureButtonThemeData value)?) → TResult?

Available on ThreeDSecureButtonThemeData, provided by the ThreeDSecureButtonThemeDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ThreeDSecureButtonThemeData value)?, {required TResult orElse()}) → TResult

Available on ThreeDSecureButtonThemeData, provided by the ThreeDSecureButtonThemeDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? backgroundColor, double? cornerRadius, String? textColor, double? textFontSize)?, {required TResult orElse()}) → TResult

Available on ThreeDSecureButtonThemeData, provided by the ThreeDSecureButtonThemeDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ThreeDSecureButtonThemeData to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? backgroundColor, double? cornerRadius, String? textColor, double? textFontSize)) → TResult

Available on ThreeDSecureButtonThemeData, provided by the ThreeDSecureButtonThemeDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? backgroundColor, double? cornerRadius, String? textColor, double? textFontSize)?) → TResult?

Available on ThreeDSecureButtonThemeData, provided by the ThreeDSecureButtonThemeDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited