ThreeDSecureTextFieldThemeData class abstract

Styling info related to the 3d secure text field.

Available extensions
Annotations
  • @freezed

Constructors

ThreeDSecureTextFieldThemeData({String? borderColor, double? borderWidth, double? cornerRadius, String? textColor, double? textFontSize})
const
factory
ThreeDSecureTextFieldThemeData.fromJson(Map<String, dynamic> json)
factory

Properties

borderColor String?
Color in hex for the border
no setterinherited
borderWidth double?
Thickness of the textfield border.
no setterinherited
copyWith → $ThreeDSecureTextFieldThemeDataCopyWith<ThreeDSecureTextFieldThemeData>
Create a copy of ThreeDSecureTextFieldThemeData with the given fields replaced by the non-null parameter values.
no setterinherited
cornerRadius double?
Radius for the textfield corners.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor String?
Color in hex for the textfield value.
no setterinherited
textFontSize double?
Font size for the textfield text.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ThreeDSecureTextFieldThemeData value)) → TResult

Available on ThreeDSecureTextFieldThemeData, provided by the ThreeDSecureTextFieldThemeDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ThreeDSecureTextFieldThemeData value)?) → TResult?

Available on ThreeDSecureTextFieldThemeData, provided by the ThreeDSecureTextFieldThemeDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ThreeDSecureTextFieldThemeData value)?, {required TResult orElse()}) → TResult

Available on ThreeDSecureTextFieldThemeData, provided by the ThreeDSecureTextFieldThemeDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? borderColor, double? borderWidth, double? cornerRadius, String? textColor, double? textFontSize)?, {required TResult orElse()}) → TResult

Available on ThreeDSecureTextFieldThemeData, provided by the ThreeDSecureTextFieldThemeDataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ThreeDSecureTextFieldThemeData to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? borderColor, double? borderWidth, double? cornerRadius, String? textColor, double? textFontSize)) → TResult

Available on ThreeDSecureTextFieldThemeData, provided by the ThreeDSecureTextFieldThemeDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? borderColor, double? borderWidth, double? cornerRadius, String? textColor, double? textFontSize)?) → TResult?

Available on ThreeDSecureTextFieldThemeData, provided by the ThreeDSecureTextFieldThemeDataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited