descriptorCode property
The descriptor code that is part of the microdepot to the customer bank account.
When Using this field make sure amounts is null.
Implementation
List<int>? get amounts;/// The descriptor code that is part of the microdepot to the customer bank account.
///
/// When Using this field make sure [amounts] is `null`.
String? get descriptorCode;