BankAccountTokenParams class abstract
parameters needed to create a token for bank account
- Available extensions
- Annotations
-
- @freezed
Constructors
- BankAccountTokenParams({@Default.new(TokenType.BankAccount) TokenType type, required String accountNumber, required String country, required String currency, String? accountHolderName, BankAccountHolderType? accountHolderType, String? routingNumber})
-
constfactory
-
BankAccountTokenParams.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountHolderName → String?
-
Full name of the account holder
no setterinherited
- accountHolderType → BankAccountHolderType?
-
Entity that is holder of the account.
no setterinherited
- accountNumber → String
-
unique number of the account.
no setterinherited
-
copyWith
→ $BankAccountTokenParamsCopyWith<
BankAccountTokenParams> -
Create a copy of BankAccountTokenParams
with the given fields replaced by the non-null parameter values.
no setterinherited
- country → String
-
2 letter code of the country where the account is located
no setterinherited
- currency → String
-
The three letter ISO 4217 code for the currency.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- routingNumber → String?
-
The routing number of the bank account (e.g. needer for US accounts).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → TokenType
-
Type of token.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_BankAccountTokenParams value)) → TResult -
Available on BankAccountTokenParams, provided by the BankAccountTokenParamsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_BankAccountTokenParams value)?) → TResult? -
Available on BankAccountTokenParams, provided by the BankAccountTokenParamsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_BankAccountTokenParams value)?, {required TResult orElse()}) → TResult -
Available on BankAccountTokenParams, provided by the BankAccountTokenParamsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(TokenType type, String accountNumber, String country, String currency, String? accountHolderName, BankAccountHolderType? accountHolderType, String? routingNumber)?, {required TResult orElse()}) → TResult -
Available on BankAccountTokenParams, provided by the BankAccountTokenParamsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BankAccountTokenParams to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(TokenType type, String accountNumber, String country, String currency, String? accountHolderName, BankAccountHolderType? accountHolderType, String? routingNumber)) → TResult -
Available on BankAccountTokenParams, provided by the BankAccountTokenParamsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(TokenType type, String accountNumber, String country, String currency, String? accountHolderName, BankAccountHolderType? accountHolderType, String? routingNumber)?) → TResult? -
Available on BankAccountTokenParams, provided by the BankAccountTokenParamsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited