CardDetails class abstract
Credit Card Details
- Available extensions
- Annotations
-
- @freezed
Constructors
- CardDetails({String? number, int? expirationYear, int? expirationMonth, String? cvc})
-
factory
-
CardDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $CardDetailsCopyWith<
CardDetails> -
Create a copy of CardDetails
with the given fields replaced by the non-null parameter values.
no setterinherited
- cvc → String?
-
no setterinherited
- expirationMonth → int?
-
no setterinherited
- expirationYear → int?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- number → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_CardDetailsConstructor value)) → TResult -
Available on CardDetails, provided by the CardDetailsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CardDetailsConstructor value)?) → TResult? -
Available on CardDetails, provided by the CardDetailsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CardDetailsConstructor value)?, {required TResult orElse()}) → TResult -
Available on CardDetails, provided by the CardDetailsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? number, int? expirationYear, int? expirationMonth, String? cvc)?, {required TResult orElse()}) → TResult -
Available on CardDetails, provided by the CardDetailsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CardDetails to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? number, int? expirationYear, int? expirationMonth, String? cvc)) → TResult -
Available on CardDetails, provided by the CardDetailsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? number, int? expirationYear, int? expirationMonth, String? cvc)?) → TResult? -
Available on CardDetails, provided by the CardDetailsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited