CardPlaceholder class abstract
Localized text for the placeholders of the card fields.
- Available extensions
- Annotations
-
- @freezed
Constructors
- CardPlaceholder({String? number, String? expiration, String? cvc, String? postalCode})
-
factory
-
CardPlaceholder.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $CardPlaceholderCopyWith<
CardPlaceholder> -
Create a copy of CardPlaceholder
with the given fields replaced by the non-null parameter values.
no setterinherited
- cvc → String?
-
Localized placeholder for cvc field.
no setterinherited
- expiration → String?
-
Localized placeholder for expiration field.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- number → String?
-
Localized placeholder for card number field.
no setterinherited
- postalCode → String?
-
Localized placeholder for postal code field.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
CardPlaceholder? placeholder) → CardPlaceholder - Apply a new placeholder object on an existing placeholder.
-
map<
TResult extends Object?> (TResult $default(_CardPlaceholderConstructor value)) → TResult -
Available on CardPlaceholder, provided by the CardPlaceholderPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CardPlaceholderConstructor value)?) → TResult? -
Available on CardPlaceholder, provided by the CardPlaceholderPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CardPlaceholderConstructor value)?, {required TResult orElse()}) → TResult -
Available on CardPlaceholder, provided by the CardPlaceholderPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? number, String? expiration, String? cvc, String? postalCode)?, {required TResult orElse()}) → TResult -
Available on CardPlaceholder, provided by the CardPlaceholderPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CardPlaceholder to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? number, String? expiration, String? cvc, String? postalCode)) → TResult -
Available on CardPlaceholder, provided by the CardPlaceholderPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? number, String? expiration, String? cvc, String? postalCode)?) → TResult? -
Available on CardPlaceholder, provided by the CardPlaceholderPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited