CheckmarkConfig class abstract
Describes the appearance of the checkmark
- Available extensions
- Annotations
-
- @freezed
Constructors
- CheckmarkConfig({@JsonKey.new(toJson: ColorKey.toJson, fromJson: ColorKey.fromJson) Color? color})
-
constfactory
-
CheckmarkConfig.fromJson(Map<
String, Object?> json) -
factory
Properties
- color → Color?
-
The color of the checkmark when selected, represented as a hex string #AARRGGBB or #RRGGBB.
@default The root appearance.colors.primary
no setterinherited
-
copyWith
→ $CheckmarkConfigCopyWith<
CheckmarkConfig> -
Create a copy of CheckmarkConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_CheckmarkConfig value)) → TResult -
Available on CheckmarkConfig, provided by the CheckmarkConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CheckmarkConfig value)?) → TResult? -
Available on CheckmarkConfig, provided by the CheckmarkConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CheckmarkConfig value)?, {required TResult orElse()}) → TResult -
Available on CheckmarkConfig, provided by the CheckmarkConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(Color? color)?, {required TResult orElse()}) → TResult -
Available on CheckmarkConfig, provided by the CheckmarkConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CheckmarkConfig to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(Color? color)) → TResult -
Available on CheckmarkConfig, provided by the CheckmarkConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(Color? color)?) → TResult? -
Available on CheckmarkConfig, provided by the CheckmarkConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited