userInterfaceStyle property
ios only. Style options for colors in Financial connections
By default the bank account collector will automatically choose colors based on the user's system settings.
Implementation
PaymentMethodType get paymentMethodType;/// ios only. Style options for colors in Financial connections
///
/// By default the bank account collector will automatically choose colors based on the
/// user's system settings.
UserInterfaceStyle? get userInterfaceStyle;