CollectBankAccountTokenParams constructor
Implementation
@JsonSerializable(explicitToJson: true)
const factory CollectBankAccountTokenParams({
/// ios only. Style options for colors in Financial connections
///
/// By default the bank account collector will automatically choose colors based on the
/// user's system settings.
UserInterfaceStyle? userInterfaceStyle,
/// An optional event listener to receive [FinancialConnectionsEvent] for
/// specific events during the process of a user connecting their financial accounts.
@JsonKey(includeFromJson: false, includeToJson: false)
FinancialConnectionsEventHandler? onEvent,
}) = _CollectBankAccountTokenParams;