appearance property
Appearance of the customersheet.
When no appearance defined it will fallback to style or Stripe default.
Implementation
@JsonKey(toJson: UserInterfaceStyleKey.toJson) ThemeMode? get style;/// Appearance of the customersheet.
///
/// When no appearance defined it will fallback to [style] or Stripe default.
PaymentSheetAppearance? get appearance;