returnURL property
URL that redirects back to your app that CustomerSheet can use to auto-dismiss web views used for additional authentication, e.g. 3DS2
Implementation
BillingDetailsCollectionConfiguration? get billingDetailsCollectionConfiguration;/// URL that redirects back to your app that CustomerSheet can use to auto-dismiss web views used for additional authentication, e.g. 3DS2
String? get returnURL;