CustomerSheetPresentParams class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- CustomerSheetPresentParams({CustomerSheetPresentationStyle? presentationStyle, CustomerSheetAnimationStyle? animationStyle, int? timeout})
-
constfactory
-
CustomerSheetPresentParams.fromJson(Map<
String, dynamic> json) -
factory
Properties
- animationStyle → CustomerSheetAnimationStyle?
-
Controls how the modal animates. iOS only.
no setterinherited
-
copyWith
→ $CustomerSheetPresentParamsCopyWith<
CustomerSheetPresentParams> -
Create a copy of CustomerSheetPresentParams
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- presentationStyle → CustomerSheetPresentationStyle?
-
Controls how the modal is presented (after animation). iOS only. Defaults to
popover. See https://developer.apple.com/documentation/uikit/uimodalpresentationstyle for more info.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → int?
-
Time (in milliseconds) before the Customer Sheet will automatically dismiss.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_CustomerSheetPresentParams value)) → TResult -
Available on CustomerSheetPresentParams, provided by the CustomerSheetPresentParamsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CustomerSheetPresentParams value)?) → TResult? -
Available on CustomerSheetPresentParams, provided by the CustomerSheetPresentParamsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CustomerSheetPresentParams value)?, {required TResult orElse()}) → TResult -
Available on CustomerSheetPresentParams, provided by the CustomerSheetPresentParamsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(CustomerSheetPresentationStyle? presentationStyle, CustomerSheetAnimationStyle? animationStyle, int? timeout)?, {required TResult orElse()}) → TResult -
Available on CustomerSheetPresentParams, provided by the CustomerSheetPresentParamsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CustomerSheetPresentParams to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(CustomerSheetPresentationStyle? presentationStyle, CustomerSheetAnimationStyle? animationStyle, int? timeout)) → TResult -
Available on CustomerSheetPresentParams, provided by the CustomerSheetPresentParamsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(CustomerSheetPresentationStyle? presentationStyle, CustomerSheetAnimationStyle? animationStyle, int? timeout)?) → TResult? -
Available on CustomerSheetPresentParams, provided by the CustomerSheetPresentParamsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited