FinancialConnectionsEventName enum
Values
- open → const FinancialConnectionsEventName
-
Invoked when the sheet successfully opens.
- manual_entry_initiated → const FinancialConnectionsEventName
-
Invoked when the manual entry flow is initiated.
- consent_acquired → const FinancialConnectionsEventName
-
Invoked when "Agree and continue" is selected on the consent pane.
- search_initiated → const FinancialConnectionsEventName
-
Invoked when the search bar is selected, the user inputs search terms, and receives an API response.
- institution_selected → const FinancialConnectionsEventName
-
Invoked when an institution is selected, either from featured institutions or search results.
-
Invoked when the authorization is successfully completed.
- accounts_selected → const FinancialConnectionsEventName
-
Invoked when accounts are selected and "confirm" is selected.
- success → const FinancialConnectionsEventName
-
Invoked when the flow is completed and selected accounts are correctly connected to the payment instrument.
- error → const FinancialConnectionsEventName
-
Invoked when an error is encountered. Refer to error codes for more details.
- cancel → const FinancialConnectionsEventName
-
Invoked when the flow is cancelled, typically by the user pressing the "X" button.
- flow_launched_in_browser → const FinancialConnectionsEventName
-
Invoked when the modal is launched in an external browser. After this event, no other events will be sent until the completion of the browser session.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FinancialConnectionsEventName> - A constant List of the values in this enum, in order of their declaration.