GooglePayParams class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- GooglePayParams({@Default.new(false) bool testEnv, required String merchantCountryCode, required String currencyCode, String? merchantName, bool? isEmailRequired, bool? allowCreditCards, GooglePayBillingAddressConfig? billingAddressConfig})
-
constfactory
-
GooglePayParams.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allowCreditCards → bool?
-
Set to false if you don't support credit cards.
no setterinherited
- billingAddressConfig → GooglePayBillingAddressConfig?
-
Describes the configuration for billing address collection in the Google Pay sheet.
no setterinherited
-
copyWith
→ $GooglePayParamsCopyWith<
GooglePayParams> -
Create a copy of GooglePayParams
with the given fields replaced by the non-null parameter values.
no setterinherited
- currencyCode → String
-
ISO 4217 alphabetic currency code.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmailRequired → bool?
-
Set to true to request an email address.
no setterinherited
- merchantCountryCode → String
-
ISO 3166-1 alpha-2 country code where the transaction is processed.
no setterinherited
- merchantName → String?
-
Merchant name, displayed in the Google Pay sheet.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- testEnv → bool
-
Set to true to run in a test environment with relaxed application / merchant requirements. This environment is suggested for early development and for easily testing SDK.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_GooglePayParams value)) → TResult -
Available on GooglePayParams, provided by the GooglePayParamsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_GooglePayParams value)?) → TResult? -
Available on GooglePayParams, provided by the GooglePayParamsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_GooglePayParams value)?, {required TResult orElse()}) → TResult -
Available on GooglePayParams, provided by the GooglePayParamsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(bool testEnv, String merchantCountryCode, String currencyCode, String? merchantName, bool? isEmailRequired, bool? allowCreditCards, GooglePayBillingAddressConfig? billingAddressConfig)?, {required TResult orElse()}) → TResult -
Available on GooglePayParams, provided by the GooglePayParamsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this GooglePayParams to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(bool testEnv, String merchantCountryCode, String currencyCode, String? merchantName, bool? isEmailRequired, bool? allowCreditCards, GooglePayBillingAddressConfig? billingAddressConfig)) → TResult -
Available on GooglePayParams, provided by the GooglePayParamsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(bool testEnv, String merchantCountryCode, String currencyCode, String? merchantName, bool? isEmailRequired, bool? allowCreditCards, GooglePayBillingAddressConfig? billingAddressConfig)?) → TResult? -
Available on GooglePayParams, provided by the GooglePayParamsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited