IntentConfiguration class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
IntentConfiguration({required IntentMode mode, List<
String> ? paymentMethodTypes, String? paymentMethodConfigurationId, @JsonKey.new(includeFromJson: false, includeToJson: false) ConfirmHandler? confirmHandler, @JsonKey.new(includeFromJson: false, includeToJson: false) ConfirmTokenHandler? confirmTokenHandler}) -
constfactory
-
IntentConfiguration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- confirmHandler → ConfirmHandler?
-
Called when the customer confirms payment. Your implementation should create
a payment intent or setupintent on your server and call the intent creation callback with its client secret or an error if one occurred.
no setterinherited
- confirmTokenHandler → ConfirmTokenHandler?
-
Called when the customer confirms token payment.
no setterinherited
-
copyWith
→ $IntentConfigurationCopyWith<
IntentConfiguration> -
Create a copy of IntentConfiguration
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → IntentMode
-
Data related to the future payment intent
no setterinherited
- paymentMethodConfigurationId → String?
-
Configuration ID for the selected payment method configuration.
See https://stripe.com/docs/payments/multiple-payment-method-configs
no setterinherited
-
paymentMethodTypes
→ List<
String> ? -
The list of payment method types that the customer can use in the payment sheet.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_IntentConfiguration value)) → TResult -
Available on IntentConfiguration, provided by the IntentConfigurationPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_IntentConfiguration value)?) → TResult? -
Available on IntentConfiguration, provided by the IntentConfigurationPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_IntentConfiguration value)?, {required TResult orElse()}) → TResult -
Available on IntentConfiguration, provided by the IntentConfigurationPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(IntentMode mode, List< String> ? paymentMethodTypes, String? paymentMethodConfigurationId, ConfirmHandler? confirmHandler, ConfirmTokenHandler? confirmTokenHandler)?, {required TResult orElse()}) → TResult -
Available on IntentConfiguration, provided by the IntentConfigurationPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this IntentConfiguration to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(IntentMode mode, List< String> ? paymentMethodTypes, String? paymentMethodConfigurationId, ConfirmHandler? confirmHandler, ConfirmTokenHandler? confirmTokenHandler)) → TResult -
Available on IntentConfiguration, provided by the IntentConfigurationPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(IntentMode mode, List< String> ? paymentMethodTypes, String? paymentMethodConfigurationId, ConfirmHandler? confirmHandler, ConfirmTokenHandler? confirmTokenHandler)?) → TResult? -
Available on IntentConfiguration, provided by the IntentConfigurationPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited