IntentCreationCallbackParams class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- IntentCreationCallbackParams({String? clientSecret, StripeException? error})
-
constfactory
-
IntentCreationCallbackParams.fromJson(Map<
String, dynamic> json) -
factory
Properties
- clientSecret → String?
-
Client secret of the payment intent or setup intent.
no setterinherited
-
copyWith
→ $IntentCreationCallbackParamsCopyWith<
IntentCreationCallbackParams> -
Create a copy of IntentCreationCallbackParams
with the given fields replaced by the non-null parameter values.
no setterinherited
- error → StripeException?
-
Error that occurred during the creation of the payment intent or setup intent.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_IntentCreationCallbackParams value)) → TResult -
Available on IntentCreationCallbackParams, provided by the IntentCreationCallbackParamsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_IntentCreationCallbackParams value)?) → TResult? -
Available on IntentCreationCallbackParams, provided by the IntentCreationCallbackParamsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_IntentCreationCallbackParams value)?, {required TResult orElse()}) → TResult -
Available on IntentCreationCallbackParams, provided by the IntentCreationCallbackParamsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? clientSecret, StripeException? error)?, {required TResult orElse()}) → TResult -
Available on IntentCreationCallbackParams, provided by the IntentCreationCallbackParamsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this IntentCreationCallbackParams to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? clientSecret, StripeException? error)) → TResult -
Available on IntentCreationCallbackParams, provided by the IntentCreationCallbackParamsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? clientSecret, StripeException? error)?) → TResult? -
Available on IntentCreationCallbackParams, provided by the IntentCreationCallbackParamsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited