error property
Error that occurred during the creation of the payment intent or setup intent.
Implementation
String? get clientSecret;/// Error that occurred during the creation of the payment intent or setup intent.
StripeException? get error;
Error that occurred during the creation of the payment intent or setup intent.
String? get clientSecret;/// Error that occurred during the creation of the payment intent or setup intent.
StripeException? get error;