captureMethod property
How the funds will be caputure from the customer's account.
Implementation
bool get livemode;/// How the funds will be caputure from the customer's account.
CaptureMethod get captureMethod;
How the funds will be caputure from the customer's account.
bool get livemode;/// How the funds will be caputure from the customer's account.
CaptureMethod get captureMethod;