receiptEmail property
Email address where the receipt will be send to.
Implementation
String? get description;/// Email address where the receipt will be send to.
String? get receiptEmail;
Email address where the receipt will be send to.
String? get description;/// Email address where the receipt will be send to.
String? get receiptEmail;