onOrderTracking property
For iOS only. If implemented, the callback is executed when an order is about to be completed and the developer needs to provide the tracking information. This method needs to call 'Stripe.instance.configurePlatformOrderTracking' with that info for setting the order details (retrieved from your server) to give users the ability to track and manage their purchases in Wallet
See https://stripe.com/docs/apple-pay?platform=ios&locale=es-ES#order-tracking
Implementation
final OnOrderTracking? onOrderTracking;