PlatformPayShippingContact class abstract
Entered Shipping contact data
- Available extensions
- Annotations
-
- @freezed
Constructors
- PlatformPayShippingContact({String? emailAddress, required ApplePayContactName name, required ApplePayPostalAddress postalAddress, String? phoneNumber})
-
constfactory
-
PlatformPayShippingContact.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $PlatformPayShippingContactCopyWith<
PlatformPayShippingContact> -
Create a copy of PlatformPayShippingContact
with the given fields replaced by the non-null parameter values.
no setterinherited
- emailAddress → String?
-
Email address of the shipping contact
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → ApplePayContactName
-
Name of shipping contact
no setterinherited
- phoneNumber → String?
-
Phone Number of the shipping contact
no setterinherited
- postalAddress → ApplePayPostalAddress
-
Postal address of shipping contact
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_PlatformPayShippingContact value)) → TResult -
Available on PlatformPayShippingContact, provided by the PlatformPayShippingContactPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_PlatformPayShippingContact value)?) → TResult? -
Available on PlatformPayShippingContact, provided by the PlatformPayShippingContactPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_PlatformPayShippingContact value)?, {required TResult orElse()}) → TResult -
Available on PlatformPayShippingContact, provided by the PlatformPayShippingContactPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? emailAddress, ApplePayContactName name, ApplePayPostalAddress postalAddress, String? phoneNumber)?, {required TResult orElse()}) → TResult -
Available on PlatformPayShippingContact, provided by the PlatformPayShippingContactPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PlatformPayShippingContact to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? emailAddress, ApplePayContactName name, ApplePayPostalAddress postalAddress, String? phoneNumber)) → TResult -
Available on PlatformPayShippingContact, provided by the PlatformPayShippingContactPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? emailAddress, ApplePayContactName name, ApplePayPostalAddress postalAddress, String? phoneNumber)?) → TResult? -
Available on PlatformPayShippingContact, provided by the PlatformPayShippingContactPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited