label property
A name that the browser shows the customer in the payment interface.
Implementation
num get amount;/// A name that the browser shows the customer in the payment interface.
String get label;
A name that the browser shows the customer in the payment interface.
num get amount;/// A name that the browser shows the customer in the payment interface.
String get label;