PlatformPayWebShippingOption class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- PlatformPayWebShippingOption({required String id, required String label, required String detail, required num amount})
-
constfactory
-
PlatformPayWebShippingOption.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → num
-
The amount to show for this shipping option. If the cost of this shipping option depends on the shipping address
the customer enters, listen for the shippingaddresschange event.
no setterinherited
-
copyWith
→ $PlatformPayWebShippingOptionCopyWith<
PlatformPayWebShippingOption> -
Create a copy of PlatformPayWebShippingOption
with the given fields replaced by the non-null parameter values.
no setterinherited
- detail → String
-
A longer description of this shipping option.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
A unique ID you create to keep track of this shipping option. You’ll be told the ID of the selected option
on changes and on completion.
no setterinherited
- label → String
-
A short label for this shipping option.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_$ShippingOption value)) → TResult -
Available on PlatformPayWebShippingOption, provided by the PlatformPayWebShippingOptionPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_$ShippingOption value)?) → TResult? -
Available on PlatformPayWebShippingOption, provided by the PlatformPayWebShippingOptionPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_$ShippingOption value)?, {required TResult orElse()}) → TResult -
Available on PlatformPayWebShippingOption, provided by the PlatformPayWebShippingOptionPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String label, String detail, num amount)?, {required TResult orElse()}) → TResult -
Available on PlatformPayWebShippingOption, provided by the PlatformPayWebShippingOptionPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PlatformPayWebShippingOption to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String label, String detail, num amount)) → TResult -
Available on PlatformPayWebShippingOption, provided by the PlatformPayWebShippingOptionPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String label, String detail, num amount)?) → TResult? -
Available on PlatformPayWebShippingOption, provided by the PlatformPayWebShippingOptionPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited