amount property
The amount to show for this shipping option. If the cost of this shipping option depends on the shipping address the customer enters, listen for the shippingaddresschange event.
Implementation
String get detail;/// The amount to show for this shipping option. If the cost of this shipping option depends on the shipping address
/// the customer enters, listen for the shippingaddresschange event.
num get amount;