paymentMethodTypes property
List of payment method types associated with this intent.
Implementation
String get usage;/// List of payment method types associated with this intent.
List<PaymentMethodType> get paymentMethodTypes;
List of payment method types associated with this intent.
String get usage;/// List of payment method types associated with this intent.
List<PaymentMethodType> get paymentMethodTypes;