setupIntentClientSecret property
The client secret of this SetupIntent
If this value is null make sure to add a paymentIntentClientSecret
Implementation
String? get paymentIntentClientSecret;/// The client secret of this SetupIntent
///
/// If this value is null make sure to add a [paymentIntentClientSecret]
String? get setupIntentClientSecret;