termsDisplay property
- @JsonKey.new(toJson: _termsDisplayToJson, fromJson: _termsDisplayFromJson)
inherited
A map of payment method types to their terms display configuration.
Controls whether legal agreements (e.g. card mandate disclaimers) are shown for each payment method type.
Keys are snake_case payment method type strings (e.g. "card", "us_bank_account").
See https://docs.stripe.com/api/payment_methods/object#payment_method_object-type for the full list of values.
Values are TermsDisplay.automatic or TermsDisplay.never.
If not set, defaults to TermsDisplay.automatic for all payment method types.
Implementation
bool? get opensCardScannerAutomatically;/// A map of payment method types to their terms display configuration.
/// Controls whether legal agreements (e.g. card mandate disclaimers) are shown for each payment method type.
/// Keys are snake_case payment method type strings (e.g. "card", "us_bank_account").
/// See https://docs.stripe.com/api/payment_methods/object#payment_method_object-type for the full list of values.
/// Values are `TermsDisplay.automatic` or `TermsDisplay.never`.
/// If not set, defaults to `TermsDisplay.automatic` for all payment method types.
@JsonKey(toJson: _termsDisplayToJson, fromJson: _termsDisplayFromJson) Map<String, TermsDisplay>? get termsDisplay;