collectBankAccountToken method
Future<FinancialConnectionTokenResult>
collectBankAccountToken({
- required String clientSecret,
- CollectBankAccountTokenParams params = const CollectBankAccountTokenParams(),
Call the financial connections authentication flow in order to collect a US bank account to enhance payouts.
Needs clientSecret of the stripe financial connections sessions.
For more info see Add a Financial Connections Account to a US Custom Connect.
Throws StripeError in case creating the token fails.
Implementation
Future<FinancialConnectionTokenResult> collectBankAccountToken({
required String clientSecret,
CollectBankAccountTokenParams params =
const CollectBankAccountTokenParams(),
}) async {
try {
return _platform.collectBankAccountToken(
clientSecret: clientSecret,
params: params,
);
} on StripeError {
rethrow;
}
}