intentCreationCallback method
Method used to confirm to the user that the intent is created successfull or not successfull when using a defferred payment method.
Implementation
Future<void> intentCreationCallback(
IntentCreationCallbackParams params,
) async {
await _awaitForSettings();
return await _platform.intentCreationCallback(params);
}