pollAndClearPendingStripeConnectUrls method
Retrieve and clear any pending Stripe Connect deep link URLs.
Android-only. Returns any stripe-connect:// URLs captured by the
native deep link interceptor since the last poll. On iOS this always
returns an empty list and on Web it throws WebUnsupportedError.
Implementation
Future<List<String>> pollAndClearPendingStripeConnectUrls() async {
await _awaitForSettings();
return _platform.pollAndClearPendingStripeConnectUrls();
}