StripeError<T> class
abstract
Wrapper class that represents an error with the Stripe platform.
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
- StripeError({@Default.new('Unknown error') String message, @JsonKey.new(fromJson: _dataFromJson, toJson: _dataToJson) required T code})
-
constfactory
-
StripeError.fromJson(Map<
String, dynamic> json) -
factory
Properties
- code → T
-
no setterinherited
-
copyWith
→ $StripeErrorCopyWith<
T, StripeError< T> > -
Create a copy of StripeError
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_StripeErrorGeneric< T> value)) → TResult -
Available on StripeError<
AT> , provided by the StripeErrorPatterns extensionswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_StripeErrorGeneric< T> value)?) → TResult? -
Available on StripeError<
A variant ofT> , provided by the StripeErrorPatterns extensionmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_StripeErrorGeneric< T> value)?, {required TResult orElse()}) → TResult -
Available on StripeError<
A variant ofT> , provided by the StripeErrorPatterns extensionmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String message, T code)?, {required TResult orElse()}) → TResult -
Available on StripeError<
A variant ofT> , provided by the StripeErrorPatterns extensionwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this StripeError to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String message, T code)) → TResult -
Available on StripeError<
AT> , provided by the StripeErrorPatterns extensionswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String message, T code)?) → TResult? -
Available on StripeError<
A variant ofT> , provided by the StripeErrorPatterns extensionwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited