ThreeDSecureNavigationBarThemeData class abstract
Styling info related to the 3d secure navigation bar.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
constfactory
-
factory
Properties
- backgroundColor → String?
-
Color in hex to display navigation bar background.
no setterinherited
-
localised text of the button
no setterinherited
-
copyWith
→ $ThreeDSecureNavigationBarThemeDataCopyWith<
ThreeDSecureNavigationBarThemeData> -
Create a copy of ThreeDSecureNavigationBarThemeData
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerText → String?
-
Localised text of the header.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusBarColor → String?
-
Color in hex for the status bar.
no setterinherited
- textColor → String?
-
Color in hex to display navigation bar header text.
no setterinherited
- textFontSize → double?
-
Font size of header text.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ThreeDSecureNavigationBarThemeData value)) → TResult -
Available on ThreeDSecureNavigationBarThemeData, provided by the ThreeDSecureNavigationBarThemeDataPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ThreeDSecureNavigationBarThemeData value)?) → TResult? -
Available on ThreeDSecureNavigationBarThemeData, provided by the ThreeDSecureNavigationBarThemeDataPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ThreeDSecureNavigationBarThemeData value)?, {required TResult orElse()}) → TResult -
Available on ThreeDSecureNavigationBarThemeData, provided by the ThreeDSecureNavigationBarThemeDataPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? headerText, String? buttonText, String? textColor, String? statusBarColor, String? backgroundColor, double? textFontSize)?, {required TResult orElse()}) → TResult -
Available on ThreeDSecureNavigationBarThemeData, provided by the ThreeDSecureNavigationBarThemeDataPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ThreeDSecureNavigationBarThemeData to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? headerText, String? buttonText, String? textColor, String? statusBarColor, String? backgroundColor, double? textFontSize)) → TResult -
Available on ThreeDSecureNavigationBarThemeData, provided by the ThreeDSecureNavigationBarThemeDataPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? headerText, String? buttonText, String? textColor, String? statusBarColor, String? backgroundColor, double? textFontSize)?) → TResult? -
Available on ThreeDSecureNavigationBarThemeData, provided by the ThreeDSecureNavigationBarThemeDataPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited